require, "asciilib.i";
require, "graphlib.i";
require, "netcdf.i";
require, "color.i";
require, "mathlib.i";
require, "ncops.i";
require, "~/Climate/Projects/ACE/Devonian/devonian_forcings.i";
require, "climber3a.i";


func plot_archean_co2( void )
{

  // define the plot limits on the x-axis (important for labels on top
  // of the plot!):
  xl = 0.714286;
  xr = 0.958333;

  // express partial pressure in terms of today's concentrations:
  //  pco2_0 = 0.000280;
  //  pco2 /= pco2_0;

  window, style="notsoflat.gs";
  fma;

  plg, [0.00028,0.00028], [xl,xr], width=3, type="dot";

  local l, pco2;
  read_columns, "Data/CO2_Lsun_288K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=4, color="black";
  read_columns, "Data/CO2_Lsun_273K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=4, color="black", type="dash";
  plt, "T = 288 K (1D Model)", 0.76, .35, height=12, tosys=1, justify="LH";
  plt, "T = 273 K (1D Model)", 0.74, .09, height=12, tosys=1, justify="LH";

  // Kaufman & Xiao (2003) lower limits:
  // age: 1.4 Ga, corresponding to L/L0 = 0.894
  // lower limit: 10...200 PAL
  // PAL is not defined, I am assuming 370ppm here
  plg, [0.0037,0.0037], [0.889,0.899], width=3, color=[125,125,255];
  plg, [0.0037,0.01], [0.894,0.894], width=3, color=[125,125,255];
  plg, [0.006,0.01], [0.89,0.894], width=3, color=[125,125,255];
  plg, [0.006,0.01], [0.898,0.894], width=3, color=[125,125,255];
  //  plt, "Kaufman &", 0.894, 0.02, height=12, tosys=1,
  //    justify="CH", color=[150,150,255];
  //  plt, "Xiao (2003)", 0.894, 0.0135, height=12, tosys=1,
  //    justify="CH", color=[150,150,255];

  // Hessler et al. (2004) lower limits:
  // age: 3.2 Ga corresponding to L/L0 = 0.78
  // lower limit at 25 deg C: 0.0025 bar
  plg, [0.0025,0.0025], [0.775,0.785], width=3, color="magenta";
  plg, [0.0025,0.008], [0.78,0.78], width=3, color="magenta";
  plg, [0.005,0.008], [0.776,0.78], width=3, color="magenta";
  plg, [0.005,0.008], [0.784,0.78], width=3, color="magenta";
  //  plt, "Hessler et al. (2004)", 0.773, 0.0025, height=12, tosys=1,
  //    justify="RH", color="magenta";

  // Sheldon (2006) measurement:
  // age: 2.2 Ga corresponding to L/L0 = 0.84 
  // range: (23 /3 *3) PAL "PAL" is not defined, at some point in
  // the paper there is the conversion from 2.51e-3 bar to 6.8 PAL,
  // from which one can conclude that PAL = 370ppm:
  //  plmk, 23.*0.00037, 0.84, marker=4, msize=.5, color="red";
  //  plg, [8.,69.]*0.00037, [0.84,0.84], width=4, color="red";
  //  plg, [8.,8.]*0.00037, [0.835,0.845], width=4, color="red";
  //  plg, [69.,69.]*0.00037, [0.835,0.845], width=4, color="red";
  //  plt, "Sheldon (2006)", 0.815, 0.05, height=12, tosys=1, 
  //    justify="LH", color="red";
  // new version:
  local a, c;
  read_columns, "Data/sheldon_2006.dat", 1,a, 2,c;
  l = gough_age_to_L( a );
  c *= 0.00037;
  for( n=1; n<=numberof(l); n++ ){
    plg, [c(n)/3.,c(n)*3.], l(n)+[0,0], width=3, color="red";
    plg, [c(n)/3.,c(n)/3.], l(n)+[-0.005,+0.005], width=3, color="red";
    plg, [c(n)*3.,c(n)*3.], l(n)+[-0.005,+0.005], width=3, color="red";
  }

  // Rye et al. (1995) upper limit: ages: 2.75-2.2 Ga, corresponding
  // to L/L0 0.81 to 0.84 upper limit for 25 deg C: 10^-2.1 atm,
  // corresponding to 0.008 bar
  plg, [0.008,0.008], [0.81,0.84], width=3, color="blue";
  plg, [0.008,0.0025], [0.825,0.825], width=3, color="blue";
  plg, [0.0025,0.004], [0.825,0.829], width=3, color="blue";
  plg, [0.0025,0.004], [0.825,0.821], width=3, color="blue";
  //  plt, "Rye et al. (1995)", 0.825, 0.002, height=12, tosys=1, 
  //    justify="CH", color="blue";

  // Kah & Riding (2007) upper limit:
  // age: 1.2 Ga, corresponding to L/L0 = 0.91
  // upper limit: 0.0036 bar
  plg, [0.0036,0.0036], [0.905,0.915], width=3, color="cyan";
  plg, [0.0036,0.0012], [0.91,0.91], width=3, color="cyan";
  plg, [0.0019,0.0012], [0.906,0.91], width=3, color="cyan";
  plg, [0.0019,0.0012], [0.914,0.91], width=3, color="cyan";
  //  plt, "Kah & Riding", 0.885, 0.0027, height=12, tosys=1, 
  //    justify="CH", color="cyan";
  //  plt, "(2007)", 0.885, 0.0018, height=12, tosys=1, 
  //    justify="CH", color="cyan";
  
  // Rosing et al. (2010) upper limit:
  // the upper limit of 0.0009 bar is for 25 deg C
  plg, [0.0009,0.0009], [0.775,0.833], width=3, color="green";
  plg, [0.0009,0.0003], [0.804,0.804], width=3, color="green";
  plg, [0.00029,0.00045], [0.804,0.80], width=3, color="green";
  plg, [0.00029,0.00045], [0.804,0.808], width=3, color="green";
  //  plt, "Rosing et al. (2010)", 0.773, 0.0009, height=12, tosys=1, 
  //    justify="RH", color="green";

  // Driese et al. (2011) measurement:
  // age: 2.69 Ga, corresponding to L/L0 = 0.813
  // best estimate: 41 times PAL
  // range: 10-50 times PAL; "PAL" is not defined, at some point in 
  // the paper there is the conversion from 0.009 bar to 25 PAL,
  // from which one can derive a value of PAL = 360ppm:
  //  plmk, 41.*0.00036, 0.813, marker=4, msize=.5, color=[255,165,0];
  plg, [10.,50.]*0.00036, [0.813,0.813], width=3, color=[255,165,0];
  plg, [10.,10.]*0.00036, [0.808,0.818], width=3, color=[255,165,0];
  plg, [50.,50.]*0.00036, [0.808,0.818], width=3, color=[255,165,0];
  //  plt, "Driese et al. (2011)", 0.81, 30.*0.00036, height=12, tosys=1,
  //    justify="RH", color=[255,165,0];



  // mark important ages on top of the plot:
  ages = [4.6,3.8,2.5,0.5];
  nages = ["4.6","3.8","2.5","0.5"];
  // convert this into relative solar luminosities:
  lages = gough_age_to_L( ages );
  pldj, lages, array( 1.6, 4 ), lages, array( 1., 4 );
  for( n=1; n<=numberof(ages); n++ )
    // viewport= { 0.14, 0.75, 0.45, 0.90 }
    plt, nages(n), 0.14+(lages(n)-xl)/(xr-xl)*(0.75-0.14), 0.905, 
      tosys=0, height=18, justify="CB";

  plg, [1.,1.], [xl,xr];

  plt, "Hadean", 0.722, 1.15, tosys=1, height=12;
  plt, "Archean", 0.774, 1.15, tosys=1, height=12;
  plt, "Proterozoic", 0.873, 1.15, tosys=1, height=12;

  // mark today's climate in this plot:
  //  plmk, 1., 1., marker=4, msize=1, color="red";

  lef = 0.8875;
  top = 0.7;
  off = 1.5;
  plt, "Rye et al. (1995)", lef, top, height=12, tosys=1, 
    justify="LH", color="blue";
  plt, "Kaufman & Xiao (2003)", lef, top/off, height=12, tosys=1,
    justify="LH", color=[125,125,255];
  plt, "Hessler et al. (2004)", lef, top/(off^2), height=12, tosys=1,
    justify="LH", color="magenta";
  plt, "Sheldon (2006)", lef, top/(off^3), height=12, tosys=1, 
    justify="LH", color="red";
  plt, "Kah & Riding (2007)", lef, top/(off^4), height=12, tosys=1, 
    justify="LH", color="cyan";
  plt, "Rosing et al. (2010)", lef, top/(off^5), height=12, tosys=1, 
    justify="LH", color="green";
  plt, "Driese et al. (2011)", lef, top/(off^6), height=12, tosys=1,
    justify="LH", color=[255,165,0];


  logxy, 0, 1;
  limits, xl, xr, 0.00007, 1.6;
  //  limits, 0.675, 1.025, 0.5, 5000.;
  xytitles, "Solar luminosity relative to today", 
    "p CO_2_  (bar)",
    [-0.02,0.01];
  topxtitle, "Time before present (Gyr)", offset=0.04;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  
  pdf, "Plots/archean_co2";
  eps, "Plots/archean_co2";

}

func plot_archean_co2_ccmodel( void )
{

  // define the plot limits on the x-axis (important for labels on top
  // of the plot!):
  xl = 0.714286;
  xr = 0.958333;

  // express partial pressure in terms of today's concentrations:
  //  pco2_0 = 0.000280;
  //  pco2 /= pco2_0;

  window, style="notsoflat.gs";
  fma;

  plg, [0.00028,0.00028], [xl,xr], width=3, type="dot";

  local l, pco2;
  read_columns, "Data/CO2_Lsun_288K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=4, color=[125,125,125];
  read_columns, "Data/CO2_Lsun_273K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=4, color=[125,125,125], type="dash";
  plt, "T = 288 K (1D Model)", 0.76, .35, height=12, tosys=1, justify="LH", color=[125,125,125];
  plt, "T = 273 K (1D Model)", 0.74, .09, height=12, tosys=1, justify="LH", color=[125,125,125];

  // Kaufman & Xiao (2003) lower limits:
  // age: 1.4 Ga, corresponding to L/L0 = 0.894
  // lower limit: 10...200 PAL
  // PAL is not defined, I am assuming 370ppm here
  plg, [0.0037,0.0037], [0.889,0.899], width=3, color=[125,125,255];
  plg, [0.0037,0.01], [0.894,0.894], width=3, color=[125,125,255];
  plg, [0.006,0.01], [0.89,0.894], width=3, color=[125,125,255];
  plg, [0.006,0.01], [0.898,0.894], width=3, color=[125,125,255];
  //  plt, "Kaufman &", 0.894, 0.02, height=12, tosys=1,
  //    justify="CH", color=[150,150,255];
  //  plt, "Xiao (2003)", 0.894, 0.0135, height=12, tosys=1,
  //    justify="CH", color=[150,150,255];

  // Hessler et al. (2004) lower limits:
  // age: 3.2 Ga corresponding to L/L0 = 0.78
  // lower limit at 25 deg C: 0.0025 bar
  plg, [0.0025,0.0025], [0.775,0.785], width=3, color="magenta";
  plg, [0.0025,0.008], [0.78,0.78], width=3, color="magenta";
  plg, [0.005,0.008], [0.776,0.78], width=3, color="magenta";
  plg, [0.005,0.008], [0.784,0.78], width=3, color="magenta";
  //  plt, "Hessler et al. (2004)", 0.773, 0.0025, height=12, tosys=1,
  //    justify="RH", color="magenta";

  // Sheldon (2006) measurement:
  // age: 2.2 Ga corresponding to L/L0 = 0.84 
  // range: (23 /3 *3) PAL "PAL" is not defined, at some point in
  // the paper there is the conversion from 2.51e-3 bar to 6.8 PAL,
  // from which one can conclude that PAL = 370ppm:
  //  plmk, 23.*0.00037, 0.84, marker=4, msize=.5, color="red";
  //  plg, [8.,69.]*0.00037, [0.84,0.84], width=4, color="red";
  //  plg, [8.,8.]*0.00037, [0.835,0.845], width=4, color="red";
  //  plg, [69.,69.]*0.00037, [0.835,0.845], width=4, color="red";
  //  plt, "Sheldon (2006)", 0.815, 0.05, height=12, tosys=1, 
  //    justify="LH", color="red";
  // new version:
  local a, c;
  read_columns, "Data/sheldon_2006.dat", 1,a, 2,c;
  l = gough_age_to_L( a );
  c *= 0.00037;
  for( n=1; n<=numberof(l); n++ ){
    plg, [c(n)/3.,c(n)*3.], l(n)+[0,0], width=3, color="red";
    plg, [c(n)/3.,c(n)/3.], l(n)+[-0.005,+0.005], width=3, color="red";
    plg, [c(n)*3.,c(n)*3.], l(n)+[-0.005,+0.005], width=3, color="red";
  }

  // Rye et al. (1995) upper limit: ages: 2.75-2.2 Ga, corresponding
  // to L/L0 0.81 to 0.84 upper limit for 25 deg C: 10^-2.1 atm,
  // corresponding to 0.008 bar
  plg, [0.008,0.008], [0.81,0.84], width=3, color="blue";
  plg, [0.008,0.0025], [0.825,0.825], width=3, color="blue";
  plg, [0.0025,0.004], [0.825,0.829], width=3, color="blue";
  plg, [0.0025,0.004], [0.825,0.821], width=3, color="blue";
  //  plt, "Rye et al. (1995)", 0.825, 0.002, height=12, tosys=1, 
  //    justify="CH", color="blue";

  // Kah & Riding (2007) upper limit:
  // age: 1.2 Ga, corresponding to L/L0 = 0.91
  // upper limit: 0.0036 bar
  plg, [0.0036,0.0036], [0.905,0.915], width=3, color="cyan";
  plg, [0.0036,0.0012], [0.91,0.91], width=3, color="cyan";
  plg, [0.0019,0.0012], [0.906,0.91], width=3, color="cyan";
  plg, [0.0019,0.0012], [0.914,0.91], width=3, color="cyan";
  //  plt, "Kah & Riding", 0.885, 0.0027, height=12, tosys=1, 
  //    justify="CH", color="cyan";
  //  plt, "(2007)", 0.885, 0.0018, height=12, tosys=1, 
  //    justify="CH", color="cyan";
  
  // Rosing et al. (2010) upper limit:
  // the upper limit of 0.0009 bar is for 25 deg C
  plg, [0.0009,0.0009], [0.775,0.833], width=3, color="green";
  plg, [0.0009,0.0003], [0.804,0.804], width=3, color="green";
  plg, [0.00029,0.00045], [0.804,0.80], width=3, color="green";
  plg, [0.00029,0.00045], [0.804,0.808], width=3, color="green";
  //  plt, "Rosing et al. (2010)", 0.773, 0.0009, height=12, tosys=1, 
  //    justify="RH", color="green";

  // Driese et al. (2011) measurement:
  // age: 2.69 Ga, corresponding to L/L0 = 0.813
  // best estimate: 41 times PAL
  // range: 10-50 times PAL; "PAL" is not defined, at some point in 
  // the paper there is the conversion from 0.009 bar to 25 PAL,
  // from which one can derive a value of PAL = 360ppm:
  //  plmk, 41.*0.00036, 0.813, marker=4, msize=.5, color=[255,165,0];
  plg, [10.,50.]*0.00036, [0.813,0.813], width=3, color=[255,165,0];
  plg, [10.,10.]*0.00036, [0.808,0.818], width=3, color=[255,165,0];
  plg, [50.,50.]*0.00036, [0.808,0.818], width=3, color=[255,165,0];
  //  plt, "Driese et al. (2011)", 0.81, 30.*0.00036, height=12, tosys=1,
  //    justify="RH", color=[255,165,0];

  // read Werner's model result and plot it on top of everything:
  local a_cc, c_cc;
  read_columns, "Data/von-bloh_pco2_fast.dat", 1,a_cc, 2,c_cc;
  // convert age to solar luminosity:
  l_cc = gough_age_to_L( a_cc );
  // plot the model:
  plg, c_cc, l_cc, width=5, color="black";


  // mark important ages on top of the plot:
  ages = [4.6,3.8,2.5,0.5];
  nages = ["4.6","3.8","2.5","0.5"];
  // convert this into relative solar luminosities:
  lages = gough_age_to_L( ages );
  pldj, lages, array( 1.6, 4 ), lages, array( 1., 4 );
  for( n=1; n<=numberof(ages); n++ )
    // viewport= { 0.14, 0.75, 0.45, 0.90 }
    plt, nages(n), 0.14+(lages(n)-xl)/(xr-xl)*(0.75-0.14), 0.905, 
      tosys=0, height=18, justify="CB";

  plg, [1.,1.], [xl,xr];

  plt, "Hadean", 0.722, 1.15, tosys=1, height=12;
  plt, "Archean", 0.774, 1.15, tosys=1, height=12;
  plt, "Proterozoic", 0.873, 1.15, tosys=1, height=12;

  // mark today's climate in this plot:
  //  plmk, 1., 1., marker=4, msize=1, color="red";

  lef = 0.8875;
  top = 0.7;
  off = 1.5;
  plt, "Rye et al. (1995)", lef, top, height=12, tosys=1, 
    justify="LH", color="blue";
  plt, "Kaufman & Xiao (2003)", lef, top/off, height=12, tosys=1,
    justify="LH", color=[125,125,255];
  plt, "Hessler et al. (2004)", lef, top/(off^2), height=12, tosys=1,
    justify="LH", color="magenta";
  plt, "Sheldon (2006)", lef, top/(off^3), height=12, tosys=1, 
    justify="LH", color="red";
  plt, "Kah & Riding (2007)", lef, top/(off^4), height=12, tosys=1, 
    justify="LH", color="cyan";
  plt, "Rosing et al. (2010)", lef, top/(off^5), height=12, tosys=1, 
    justify="LH", color="green";
  plt, "Driese et al. (2011)", lef, top/(off^6), height=12, tosys=1,
    justify="LH", color=[255,165,0];


  logxy, 0, 1;
  limits, xl, xr, 0.00007, 1.6;
  //  limits, 0.675, 1.025, 0.5, 5000.;
  xytitles, "Solar luminosity relative to today", 
    "p CO_2_  (bar)",
    [-0.02,0.01];
  topxtitle, "Time before present (Gyr)", offset=0.04;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  
  pdf, "Plots/archean_co2_ccmodel";
  eps, "Plots/archean_co2_ccmodel";

}


func plot_archean_co2_ccmodel_v2( void )
{

  // define the plot limits on the x-axis (important for labels on top
  // of the plot!):
  xl = 0.714286;
  xr = 0.958333;

  window, style="notsoflat.gs";
  fma;

  local l, pco2;
  read_columns, "Data/CO2_Lsun_273K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=2, color=[0,125,200];
  for( n=1; n<=20; n++ )
    plg, pco2/1.5^n, l, width=2, color=[0,125,200];


  // Kaufman & Xiao (2003) lower limits:
  // age: 1.4 Ga, corresponding to L/L0 = 0.894
  // lower limit: 10...200 PAL
  // PAL is not defined, I am assuming 370ppm here
  plg, [0.0037,0.0037], [0.889,0.899], width=3, color=[125,125,125];
  plg, [0.0037,0.01], [0.894,0.894], width=3, color=[125,125,125];
  plg, [0.006,0.01], [0.89,0.894], width=3, color=[125,125,125];
  plg, [0.006,0.01], [0.898,0.894], width=3, color=[125,125,125];

  // Hessler et al. (2004) lower limits:
  // age: 3.2 Ga corresponding to L/L0 = 0.78
  // lower limit at 25 deg C: 0.0025 bar
  plg, [0.0025,0.0025], [0.775,0.785], width=3, color=[125,125,125];
  plg, [0.0025,0.008], [0.78,0.78], width=3, color=[125,125,125];
  plg, [0.005,0.008], [0.776,0.78], width=3, color=[125,125,125];
  plg, [0.005,0.008], [0.784,0.78], width=3, color=[125,125,125];

  // Sheldon (2006) measurement:
  // age: 2.2 Ga corresponding to L/L0 = 0.84 
  // range: (23 /3 *3) PAL "PAL" is not defined, at some point in
  // the paper there is the conversion from 2.51e-3 bar to 6.8 PAL,
  // from which one can conclude that PAL = 370ppm:
  //  plmk, 23.*0.00037, 0.84, marker=4, msize=.5, color="red";
  //  plg, [8.,69.]*0.00037, [0.84,0.84], width=4, color="red";
  //  plg, [8.,8.]*0.00037, [0.835,0.845], width=4, color="red";
  //  plg, [69.,69.]*0.00037, [0.835,0.845], width=4, color="red";
  //  plt, "Sheldon (2006)", 0.815, 0.05, height=12, tosys=1, 
  //    justify="LH", color="red";
  // new version:
  local a, c;
  read_columns, "Data/sheldon_2006.dat", 1,a, 2,c;
  l = gough_age_to_L( a );
  c *= 0.00037;
  for( n=1; n<=numberof(l); n++ ){
    plg, [c(n)/3.,c(n)*3.], l(n)+[0,0], width=3, color=[125,125,125];
    plg, [c(n)/3.,c(n)/3.], l(n)+[-0.005,+0.005], width=3, color=[125,125,125];
    plg, [c(n)*3.,c(n)*3.], l(n)+[-0.005,+0.005], width=3, color=[125,125,125];
  }

  // Rye et al. (1995) upper limit: ages: 2.75-2.2 Ga, corresponding
  // to L/L0 0.81 to 0.84 upper limit for 25 deg C: 10^-2.1 atm,
  // corresponding to 0.008 bar
  plg, [0.008,0.008], [0.81,0.84], width=3, color=[125,125,125];
  plg, [0.008,0.0025], [0.825,0.825], width=3, color=[125,125,125];
  plg, [0.0025,0.004], [0.825,0.829], width=3, color=[125,125,125];
  plg, [0.0025,0.004], [0.825,0.821], width=3, color=[125,125,125];

  // Kah & Riding (2007) upper limit:
  // age: 1.2 Ga, corresponding to L/L0 = 0.91
  // upper limit: 0.0036 bar
  plg, [0.0036,0.0036], [0.905,0.915], width=3, color=[125,125,125];
  plg, [0.0036,0.0012], [0.91,0.91], width=3, color=[125,125,125];
  plg, [0.0019,0.0012], [0.906,0.91], width=3, color=[125,125,125];
  plg, [0.0019,0.0012], [0.914,0.91], width=3, color=[125,125,125];
  
  // Rosing et al. (2010) upper limit:
  // the upper limit of 0.0009 bar is for 25 deg C
  plg, [0.0009,0.0009], [0.775,0.833], width=3, color=[125,125,125];
  plg, [0.0009,0.0003], [0.804,0.804], width=3, color=[125,125,125];
  plg, [0.00029,0.00045], [0.804,0.80], width=3, color=[125,125,125];
  plg, [0.00029,0.00045], [0.804,0.808], width=3, color=[125,125,125];

  // Driese et al. (2011) measurement:
  // age: 2.69 Ga, corresponding to L/L0 = 0.813
  // best estimate: 41 times PAL
  // range: 10-50 times PAL; "PAL" is not defined, at some point in 
  // the paper there is the conversion from 0.009 bar to 25 PAL,
  // from which one can derive a value of PAL = 360ppm:
  //  plmk, 41.*0.00036, 0.813, marker=4, msize=.5, color=[255,165,0];
  plg, [10.,50.]*0.00036, [0.813,0.813], width=3, color=[125,125,125];
  plg, [10.,10.]*0.00036, [0.808,0.818], width=3, color=[125,125,125];
  plg, [50.,50.]*0.00036, [0.808,0.818], width=3, color=[125,125,125];

  // read Werner's model result and plot it on top of everything:
  local a_cc, c_cc;
  read_columns, "Data/von-bloh_pco2_fast.dat", 1,a_cc, 2,c_cc;
  // convert age to solar luminosity:
  l_cc = gough_age_to_L( a_cc );
  // plot the model:
  plg, c_cc, l_cc, width=6, color="red";


  // mark important ages on top of the plot:
  ages = [4.6,3.8,2.5,0.5];
  nages = ["4.6","3.8","2.5","0.5"];
  // convert this into relative solar luminosities:
  lages = gough_age_to_L( ages );
  pldj, lages, array( 1.6, 4 ), lages, array( 1., 4 );
  for( n=1; n<=numberof(ages); n++ )
    // viewport= { 0.14, 0.75, 0.45, 0.90 }
    plt, nages(n), 0.14+(lages(n)-xl)/(xr-xl)*(0.75-0.14), 0.905, 
      tosys=0, height=18, justify="CB";

  plg, [1.,1.], [xl,xr];

  plt, "Hadean", 0.722, 1.15, tosys=1, height=12;
  plt, "Archean", 0.774, 1.15, tosys=1, height=12;
  plt, "Proterozoic", 0.873, 1.15, tosys=1, height=12;

  pli, [[1,1],[1,1]], 0.7275, 0.00013, 0.8025, 0.00024;
  plt, "Uninhabitable regime", 0.73, .000175, height=14, tosys=1, justify="LH", color=[0,125,200];
  plt, "Carbon-cycle-climate model", 0.75, 0.1, height=14, tosys=1, 
    justify="LH", color="red";
  plt, "Geochemical constraints", 0.8725, 0.03, height=14, tosys=1,
    justify="LH", color=[125,125,125];


  logxy, 0, 1;
  limits, xl, xr, 0.00007, 1.6;
  //  limits, 0.675, 1.025, 0.5, 5000.;
  xytitles, "Solar luminosity relative to today", 
    "Carbon dioxide partial pressure  (bar)",
    [-0.02,0.01];
  topxtitle, "Time before present (Gyr)", offset=0.04;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  
  pdf, "Plots/archean_co2_ccmodel_v2";
  eps, "Plots/archean_co2_ccmodel_v2";
  png, "Plots/archean_co2_ccmodel_v2", dpi=600;

}



// modified copy of the "review version" plot_archean_co2
func plot_archean_co2_3d( nature=, only_1d= )
{

  // define the plot limits on the x-axis (important for labels on top
  // of the plot!):
  xl = 0.73;
  xr = 0.85;


  window, style="notsoflat.gs";
  fma;

  // Hessler et al. (2004) lower limits:
  // age: 3.2 Ga corresponding to L/L0 = 0.78
  // lower limit at 25 deg C: 0.0025 bar
  plg, [0.0025,0.0025], [0.7775,0.7825], width=2, color=[60,60,60];
  plg, [0.0025,0.008], [0.78,0.78], width=2, color=[60,60,60];
  plg, [0.005,0.008], [0.778,0.78], width=2, color=[60,60,60];
  plg, [0.005,0.008], [0.782,0.78], width=2, color=[60,60,60];
  if( is_void(nature) )
    plt, "Hessler et al. (2004)", 0.7775, 0.0045, height=14, tosys=1,
      justify="RH", color=[60,60,60];
  else
    plt, "ref. 22", 0.775, 0.0045, height=14, tosys=1,
      justify="RH", color=[60,60,60];

  // Sheldon (2006) measurement:
  // age: 2.2 Ga corresponding to L/L0 = 0.84 
  // range: (23 /3 *3) PAL "PAL" is not defined, at some point in
  // the paper there is the conversion from 2.51e-3 bar to 6.8 PAL,
  // from which one can conclude that PAL = 370ppm:
  local a, c;
  read_columns, "Data/sheldon_2006.dat", 1,a, 2,c;
  l = gough_age_to_L( a );
  c *= 0.00037;
  for( n=1; n<=2; n++ ){
    plg, [c(n)/3.,c(n)*3.], l(n)+[0,0], width=2, color=[60,60,60];
    plg, [c(n)/3.,c(n)/3.], l(n)+[-0.0025,+0.0025], width=2, color=[60,60,60];
    plg, [c(n)*3.,c(n)*3.], l(n)+[-0.0025,+0.0025], width=2, color=[60,60,60];
  }
  if( is_void(nature) )
    plt, "Sheldon (2006)", 0.8185, 0.0021, height=14, tosys=1, 
      justify="LH", color=[60,60,60];
  else
    plt, "ref. 19", 0.825, 0.0021, height=14, tosys=1, 
      justify="LH", color=[60,60,60];

  
  // Rosing et al. (2010) upper limit:
  // the upper limit of 0.0009 bar is for 25 deg C
  plg, [0.0009,0.0009], [0.775,0.833], width=2, color=[60,60,60];
  plg, [0.0009,0.0003], [0.804,0.804], width=2, color=[60,60,60];
  plg, [0.00029,0.00045], 0.804+[0,-0.002], width=2, color=[60,60,60];
  plg, [0.00029,0.00045], 0.804+[0,0.002], width=2, color=[60,60,60];
  if( is_void(nature) )
    plt, "Rosing et al. (2010)", 0.804, 0.0013, height=14, tosys=1, 
      justify="CH", color=[60,60,60];
  else
    plt, "ref. 20", 0.804, 0.0013, height=14, tosys=1, 
      justify="CH", color=[60,60,60];

  // Driese et al. (2011) measurement:
  // age: 2.69 Ga, corresponding to L/L0 = 0.813
  // best estimate: 41 times PAL
  // range: 10-50 times PAL; "PAL" is not defined, at some point in 
  // the paper there is the conversion from 0.009 bar to 25 PAL,
  // from which one can derive a value of PAL = 360ppm:
  //  plmk, 41.*0.00036, 0.813, marker=4, msize=.5, color=[255,165,0];
  plg, [10.,50.]*0.00036, 0.813+[0.,0.], width=2, color=[60,60,60];
  plg, [10.,10.]*0.00036, 0.813+[-0.0025,0.0025], width=2, color=[60,60,60];
  plg, [50.,50.]*0.00036, 0.813+[-0.0025,0.0025], width=2, color=[60,60,60];
  if( is_void(nature) )
    plt, "Driese et al. (2011)", 0.8125, 22.5*0.00036, height=14, tosys=1,
      justify="RH", color=[60,60,60];
  else
    plt, "ref. 21", 0.81, 22.5*0.00036, height=14, tosys=1,
      justify="RH", color=[60,60,60];



  // mark important ages on top of the plot:
  ages = [3.8,2.5];
  nages = ["3.8","2.5"];
  // convert this into relative solar luminosities:
  lages = gough_age_to_L( ages );
  pldj, lages, array( 2., 4 ), lages, array( 1.5, 4 );
  for( n=1; n<=numberof(ages); n++ )
    // viewport= { 0.14, 0.75, 0.45, 0.90 }
    plt, nages(n), 0.14+(lages(n)-xl)/(xr-xl)*(0.75-0.14), 0.905, 
      tosys=0, height=18, justify="CB";

  // plot von Paris et al. model results:
  local l, pco2;
  read_columns, "Data/CO2_Lsun_288K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=3, color="red", type="dash";
  read_columns, "Data/CO2_Lsun_273K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=3, color="blue", type="dash";
  if( is_void(nature) ){
    plt, "T = 288 K (1D model)", 0.74, .15, height=14, tosys=1, justify="LH", color="red";
    plt, "T = 273 K (1D model)", 0.74, .025, height=14, tosys=1, justify="LH", color="blue";
  }
  else{
    plt, "T = 288 K (1D model, ref. 7)", 0.735, .145, height=14, tosys=1, justify="LH", color="red";
    plt, "T = 273 K (1D model, ref. 7)", 0.735, .022, height=14, tosys=1, justify="LH", color="blue";
  }


  // plot our model results:
  if( is_void(only_1d) ){
    plmk, [0.4,0.25,0.13], [0.7525,0.79,0.82], marker=5, msize=.6, 
      color="blue";
    plmk, [0.6,0.4,0.25], [0.7525,0.79,0.82], marker=4, msize=.6, 
      color="red";
    // legend
    pldj, [0.735,0.7875,0.7875,0.735], [0.0007,0.0007,0.000225,0.000225],
      [0.7875,0.7875,0.735,0.735], [0.0007,0.000225,0.000225,0.0007],
      width=2;
    plmk, .0004, 0.74, marker=5, msize=.6, color="blue";
    plmk, .0004, 0.744, marker=4, msize=.6, color="red";
    plt, "3D model (this work)", 0.7475, .0004, height=14, tosys=1, 
      justify="LH", font="helveticaB";
  }

  logxy, 0, 1;
  limits, xl, xr, 1.5e-4, 2.;
  xytitles, "Solar luminosity relative to today", 
    "CO_2_ partial pressure  (bar)",
    [-0.02,0.01];
  topxtitle, "Time before present (Gyr)", offset=0.04;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  if( is_void(only_1d) ){
    pdf, "Plots/archean_co2_3d";
    eps, "Plots/archean_co2_3d";
    png, "Plots/archean_co2_3d", dpi=300;
  }
  else{
    pdf, "Plots/archean_co2_1d";
    eps, "Plots/archean_co2_1d";
    png, "Plots/archean_co2_1d", dpi=300;
  }
  
}


// modified copy of the "review version" plot_archean_co2
func plot_archean_co2_3d_synthesis( nature=, only_1d=, only_c3a= )
{

  // define the plot limits on the x-axis (important for labels on top
  // of the plot!):
  xl = 0.73;
  xr = 0.85;


  window, style="notsoflat.gs";
  fma;

  // Hessler et al. (2004) lower limits:
  // age: 3.2 Ga corresponding to L/L0 = 0.78
  // lower limit at 25 deg C: 0.0025 bar
  plg, [0.0025,0.0025], [0.7775,0.7825], width=2, color=[125,125,125];
  plg, [0.0025,0.008], [0.78,0.78], width=2, color=[125,125,125];
  plg, [0.005,0.008], [0.778,0.78], width=2, color=[125,125,125];
  plg, [0.005,0.008], [0.782,0.78], width=2, color=[125,125,125];
  if( is_void(nature) )
    plt, "Hessler et al. (2004)", 0.783, 0.0018, height=12, tosys=1,
      justify="RH", color=[125,125,125];
  else
    plt, "ref. 22", 0.775, 0.0045, height=14, tosys=1,
      justify="RH", color=[125,125,125];

  // Sheldon (2006) measurement:
  // age: 2.2 Ga corresponding to L/L0 = 0.84 
  // range: (23 /3 *3) PAL "PAL" is not defined, at some point in
  // the paper there is the conversion from 2.51e-3 bar to 6.8 PAL,
  // from which one can conclude that PAL = 370ppm:
  local a, c;
  read_columns, "Data/sheldon_2006.dat", 1,a, 2,c;
  l = gough_age_to_L( a );
  c *= 0.00037;
  for( n=1; n<=2; n++ ){
    plg, [c(n)/3.,c(n)*3.], l(n)+[0,0], width=2, color=[125,125,125];
    plg, [c(n)/3.,c(n)/3.], l(n)+[-0.0025,+0.0025], width=2, color=[125,125,125];
    plg, [c(n)*3.,c(n)*3.], l(n)+[-0.0025,+0.0025], width=2, color=[125,125,125];
  }
  if( is_void(nature) )
    plt, "Sheldon (2006)", 0.8205, 0.0021, height=12, tosys=1, 
      justify="LH", color=[125,125,125];
  else
    plt, "ref. 19", 0.825, 0.0021, height=14, tosys=1, 
      justify="LH", color=[125,125,125];

  
  // Rosing et al. (2010) upper limit:
  // the upper limit of 0.0009 bar is for 25 deg C
  /*
  plg, [0.0009,0.0009], [0.775,0.833], width=2, color=[125,125,125];
  plg, [0.0009,0.0003], [0.804,0.804], width=2, color=[125,125,125];
  plg, [0.00029,0.00045], 0.804+[0,-0.002], width=2, color=[125,125,125];
  plg, [0.00029,0.00045], 0.804+[0,0.002], width=2, color=[125,125,125];
  if( is_void(nature) )
    plt, "Rosing et al. (2010)", 0.804, 0.0013, height=14, tosys=1, 
      justify="CH", color=[125,125,125];
  else
    plt, "ref. 20", 0.804, 0.0013, height=14, tosys=1, 
      justify="CH", color=[125,125,125];
  */

  // Driese et al. (2011) measurement:
  // age: 2.69 Ga, corresponding to L/L0 = 0.813
  // best estimate: 41 times PAL
  // range: 10-50 times PAL; "PAL" is not defined, at some point in 
  // the paper there is the conversion from 0.009 bar to 25 PAL,
  // from which one can derive a value of PAL = 360ppm:
  //  plmk, 41.*0.00036, 0.813, marker=4, msize=.5, color=[255,165,0];
  plg, [10.,50.]*0.00036, 0.813+[0.,0.], width=2, color=[125,125,125];
  plg, [10.,10.]*0.00036, 0.813+[-0.0025,0.0025], width=2, color=[125,125,125];
  plg, [50.,50.]*0.00036, 0.813+[-0.0025,0.0025], width=2, color=[125,125,125];
  if( is_void(nature) )
    plt, "Driese et al. (2011)", 0.816, 0.0027, height=12, tosys=1,
      justify="RH", color=[125,125,125];
  else
    plt, "ref. 21", 0.81, 22.5*0.00036, height=14, tosys=1,
      justify="RH", color=[125,125,125];



  // mark important ages on top of the plot:
  ages = [3.8,2.5];
  nages = ["3.8","2.5"];
  // convert this into relative solar luminosities:
  lages = gough_age_to_L( ages );
  pldj, lages, array( 2., 4 ), lages, array( 1.5, 4 );
  for( n=1; n<=numberof(ages); n++ )
    // viewport= { 0.14, 0.75, 0.45, 0.90 }
    plt, nages(n), 0.14+(lages(n)-xl)/(xr-xl)*(0.75-0.14), 0.905, 
      tosys=0, height=18, justify="CB";

  // plot von Paris et al. model results:
  local l, pco2;
  read_columns, "Data/CO2_Lsun_288K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=3, color=[255,125,125];
  read_columns, "Data/CO2_Lsun_273K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=3, color=[125,125,255];
  if( is_void(nature) ){
    plt, "T = 288 K (1D model)", 0.733, .165, height=12, tosys=1, 
      justify="LH", color=[255,125,125];
    plt, "T = 273 K (1D model)", 0.733, .03, height=12, tosys=1, 
      justify="LH", color=[125,125,255];
  }
  else{
    plt, "T = 288 K (1D model, ref. 7)", 0.735, .145, height=14, tosys=1, justify="LH", color="red";
    plt, "T = 273 K (1D model, ref. 7)", 0.735, .022, height=14, tosys=1, justify="LH", color="blue";
  }

  if( is_void(only_1d) ){

    // Kienert et al. (2012):
    // S0: 1361 W/m2, factors as used in the simulations:
    // BC: realistic topographies, higher rotation rates
    // double-checked: 17.9.2013
    // TODO: check definition of partial pressure
    plmk, [0.4,0.25,0.13], [0.7525,0.79,0.82], marker=4, msize=.6, 
      color="blue";
    plt, "T = 268 K", 0.756, 0.4, height=10, color="blue", tosys=1,
      justify="LH";
    plt, "T = 272 K", 0.793, 0.25, height=10, color="blue", tosys=1,
      justify="LH";
    plt, "T = 270 K", 0.823, 0.13, height=10, color="blue", tosys=1,
      justify="LH";
    plmk, [0.6,0.4,0.25], [0.7525,0.79,0.82], marker=4, msize=.6, 
      color="red";
    plt, "T = 289 K", 0.756, 0.6, height=10, color="red", tosys=1,
      justify="LH";
    plt, "T = 290 K", 0.793, 0.4, height=10, color="red", tosys=1,
      justify="LH";
    plt, "T = 288 K", 0.823, 0.25, height=10, color="red", tosys=1,
      justify="LH";

    if( is_void(only_c3a) ){

      // Kunze et al. (2013):
      // S0: 1365 W/m2; solar constant values as given in the paper
      // BC: aquaplanet, present-day rotation rate, spectral irradiance
      //     from solar analogue
      // total pressure 1 bar in all simulations (M. Kunze, priv. comm.)
      // double-checked: 17.9.2013
      plmk, 3670.*1.e-6/1., 1046./1361., marker=5, msize=.6, color="blue";
      plt, "T = 264 K", 0.754, 0.0037, height=10, color="blue", tosys=1,
        justify="LH";
      plmk, 3670.*1.e-6/1., 1121./1361., marker=5, msize=.6, color="blue";
      plt, "T = 270 K", 0.826, 0.0037, height=10, color="blue", tosys=1,
        justify="LH";
      
      // Wolf & Toon (2013):
      // S0: solar constant value as given in the paper
      // total pressure 1.013 bar held constant
      // published in the paper
      // BC: present-day continents and rotation rate
      // double-checked: 17.9.2013
      plmk, 60000.*1.e-6*1.013, 1093.6/1361., marker=1, msize=.6, color="red";
      plmk, 20000.*1.e-6*1.013, 1093.6/1361., marker=1, msize=.6, color="blue";
      plt, "T = 272 K", 0.806, 0.021, height=10, color="blue", tosys=1,
        justify="LH";
      plt, "T = 288 K", 0.806, 0.06, height=10, color="red", tosys=1,
        justify="LH";
      
      // Charnay et al. (2013), no methane, modern cloud droplet size:
      // S0 = 1366 W/m2; solar constant values as given in the paper
      // mean surface pressure 1 bar, partial pressures as reported
      // in the paper
      // double-checked: 17.9.2013
      // 3.8 Ga:
      plmk, 0.01, 1025.1/1361., marker=2, msize=.6, color="blue";
      plt, "T = 256 K", 0.756, 0.01, height=10, color="blue", tosys=1,
        justify="LH";
      plmk, 0.1, 1025.1/1361., marker=2, msize=.6, color="red";
      plt, "T = 280 K", 0.756, 0.1, height=10, color="red", tosys=1,
        justify="LH";
      // 3.0 Ga:
      plmk, 0.01, 1081.9/1361., marker=2, msize=.6, color="blue";
      plt, "T = 269 K", 0.798, 0.01, height=10, color="blue", tosys=1,
        justify="LH";
      plmk, 0.1, 1081.9/1361., marker=2, msize=.6, color="red";
      plt, "T = 290 K", 0.798, 0.1, height=10, color="red", tosys=1,
        justify="LH";
      // 2.5 Ga:
      plmk, 0.01, 1120.8/1361., marker=2, msize=.6, color="blue";
      plt, "T = 271 K", 0.826, 0.01, height=10, color="blue", tosys=1,
        justify="LH";
      plmk, 0.1, 1120.8/1361., marker=2, msize=.6, color="red";
      plt, "T = 293 K", 0.826, 0.08, height=10, color="red", tosys=1,
        justify="LH";
      
      // Le Hir et al. (2013), modern cloud droplet size, 1.7e-6 CH4:
      // BC: realistic topography
      // S0 = ?;  solar constant values as given in the paper
      // double-checked: 17.9.2013
      plmk, 0.056, 1053./1361., marker=3, msize=.6, color="red";
      plt, "T = 289 K", 0.777, 0.056, height=10, color="red", tosys=1,
        justify="LH";
      plmk, 0.0252, 1053./1361., marker=3, msize=.6, color="blue", 
        width=3;
      plt, "T = 200 K", 0.777, 0.021, height=10, color="blue", tosys=1,
        justify="LH";

    }

  }
      
  logxy, 0, 1;
  limits, xl, xr, 1.5e-4, 2.;
  xytitles, "Solar luminosity relative to today", 
    "CO_2_ partial pressure  (bar)",
    [-0.02,0.01];
  topxtitle, "Time before present (Gyr)", offset=0.04;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  if( is_void(only_1d) & is_void(only_c3a) ){
    plegend, [4,5], ["Kienert et al. (2012)","Kunze et al. (2014)"], msize=.6, origin=[.1,.175];
    plegend, [2,3], ["Charnay et al. (2013)","Le Hir et al. (2014)"], msize=.6, origin=[.40,.175];
    plegend, [1], ["Wolf & Toon (2013)"], msize=.6, origin=[.7,.175];
  }
  if( is_void(only_1d) & !is_void(only_c3a) )
    plegend, [4], ["Kienert et al. (2012)"], msize=.6, origin=[.1,.175];
    



  if( is_void(only_1d) & is_void(only_c3a) ){
    pdf, "Plots/archean_co2_3d_synthesis";
    eps, "Plots/archean_co2_3d_synthesis";
    png, "Plots/archean_co2_3d_synthesis", dpi=300;
  }
  if( !is_void(only_1d) ){
    pdf, "Plots/archean_co2_1d_new";
    eps, "Plots/archean_co2_1d_new";
    png, "Plots/archean_co2_1d_new", dpi=300;
  }
  if( !is_void(only_c3a) ){
    pdf, "Plots/archean_co2_3d_new";
    eps, "Plots/archean_co2_3d_new";
    png, "Plots/archean_co2_3d_new", dpi=300;
  }
  
}


func plot_archean_co2_3d_synthesis_sfb( only_1d=, only_c3a= )
{

  // define the plot limits on the x-axis (important for labels on top
  // of the plot!):
  xl = 0.73;
  xr = 0.85;


  window, style="notsoflat.gs";
  fma;

  // Hessler et al. (2004) lower limits:
  // age: 3.2 Ga corresponding to L/L0 = 0.78
  // lower limit at 25 deg C: 0.0025 bar
  plg, [0.0025,0.0025], [0.7775,0.7825], width=2, color=[125,125,125];
  plg, [0.0025,0.008], [0.78,0.78], width=2, color=[125,125,125];
  plg, [0.005,0.008], [0.778,0.78], width=2, color=[125,125,125];
  plg, [0.005,0.008], [0.782,0.78], width=2, color=[125,125,125];
  //  plt, "Hessler et al. (2004)", 0.783, 0.0018, height=12, tosys=1,
  //      justify="RH", color=[125,125,125];
  
  // Sheldon (2006) measurement:
  // age: 2.2 Ga corresponding to L/L0 = 0.84 
  // range: (23 /3 *3) PAL "PAL" is not defined, at some point in
  // the paper there is the conversion from 2.51e-3 bar to 6.8 PAL,
  // from which one can conclude that PAL = 370ppm:
  local a, c;
  read_columns, "Data/sheldon_2006.dat", 1,a, 2,c;
  l = gough_age_to_L( a );
  c *= 0.00037;
  for( n=1; n<=2; n++ ){
    plg, [c(n)/3.,c(n)*3.], l(n)+[0,0], width=2, color=[125,125,125];
    plg, [c(n)/3.,c(n)/3.], l(n)+[-0.0025,+0.0025], width=2, color=[125,125,125];
    plg, [c(n)*3.,c(n)*3.], l(n)+[-0.0025,+0.0025], width=2, color=[125,125,125];
  }
  //  plt, "Sheldon (2006)", 0.8205, 0.0021, height=12, tosys=1, 
  //    justify="LH", color=[125,125,125];

  
  // Rosing et al. (2010) upper limit:
  // the upper limit of 0.0009 bar is for 25 deg C
  /*
  plg, [0.0009,0.0009], [0.775,0.833], width=2, color=[125,125,125];
  plg, [0.0009,0.0003], [0.804,0.804], width=2, color=[125,125,125];
  plg, [0.00029,0.00045], 0.804+[0,-0.002], width=2, color=[125,125,125];
  plg, [0.00029,0.00045], 0.804+[0,0.002], width=2, color=[125,125,125];
  if( is_void(nature) )
    plt, "Rosing et al. (2010)", 0.804, 0.0013, height=14, tosys=1, 
      justify="CH", color=[125,125,125];
  else
    plt, "ref. 20", 0.804, 0.0013, height=14, tosys=1, 
      justify="CH", color=[125,125,125];
  */

  // Driese et al. (2011) measurement:
  // age: 2.69 Ga, corresponding to L/L0 = 0.813
  // best estimate: 41 times PAL
  // range: 10-50 times PAL; "PAL" is not defined, at some point in 
  // the paper there is the conversion from 0.009 bar to 25 PAL,
  // from which one can derive a value of PAL = 360ppm:
  //  plmk, 41.*0.00036, 0.813, marker=4, msize=.5, color=[255,165,0];
  plg, [10.,50.]*0.00036, 0.813+[0.,0.], width=2, color=[125,125,125];
  plg, [10.,10.]*0.00036, 0.813+[-0.0025,0.0025], width=2, color=[125,125,125];
  plg, [50.,50.]*0.00036, 0.813+[-0.0025,0.0025], width=2, color=[125,125,125];
  //  plt, "Driese et al. (2011)", 0.816, 0.0027, height=12, tosys=1,
  //    justify="RH", color=[125,125,125];

  plt, "Geochemical constraints", 0.79, 0.001, height=14, tosys=1,
    justify="LH", color=[125,125,125];



  // mark important ages on top of the plot:
  ages = [3.8,2.5];
  nages = ["3.8","2.5"];
  // convert this into relative solar luminosities:
  lages = gough_age_to_L( ages );
  pldj, lages, array( 2., 4 ), lages, array( 1.5, 4 );
  for( n=1; n<=numberof(ages); n++ )
    // viewport= { 0.14, 0.75, 0.45, 0.90 }
    plt, nages(n), 0.14+(lages(n)-xl)/(xr-xl)*(0.75-0.14), 0.905, 
      tosys=0, height=18, justify="CB";

  // plot von Paris et al. model results:
  local l, pco2;
  read_columns, "Data/CO2_Lsun_288K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=3, color=[255,125,125];
  read_columns, "Data/CO2_Lsun_273K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=3, color=[125,125,255];
  if( is_void(nature) ){
    plt, "T = 288 K (1D model)", 0.733, .165, height=14, tosys=1, 
      justify="LH", color=[255,125,125];
    plt, "T = 273 K (1D model)", 0.733, .03, height=14, tosys=1, 
      justify="LH", color=[125,125,255];
  }
  else{
    plt, "T = 288 K (1D model, ref. 7)", 0.735, .145, height=14, tosys=1, justify="LH", color="red";
    plt, "T = 273 K (1D model, ref. 7)", 0.735, .022, height=14, tosys=1, justify="LH", color="blue";
  }

  if( is_void(only_1d) ){

    // Kienert et al. (2012):
    // S0: 1361 W/m2, factors as used in the simulations:
    // BC: realistic topographies, higher rotation rates
    // double-checked: 17.9.2013
    // TODO: check definition of partial pressure
    plmk, [0.4,0.25,0.13], [0.7525,0.79,0.82], marker=4, msize=.6, 
      color="blue";
    /*
    plt, "T = 268 K", 0.756, 0.4, height=10, color="blue", tosys=1,
      justify="LH";
    plt, "T = 272 K", 0.793, 0.25, height=10, color="blue", tosys=1,
      justify="LH";
    plt, "T = 270 K", 0.823, 0.13, height=10, color="blue", tosys=1,
      justify="LH";
    */
    plmk, [0.6,0.4,0.25], [0.7525,0.79,0.82], marker=4, msize=.6, 
      color="red";
    /*
    plt, "T = 289 K", 0.756, 0.6, height=10, color="red", tosys=1,
      justify="LH";
    plt, "T = 290 K", 0.793, 0.4, height=10, color="red", tosys=1,
      justify="LH";
    plt, "T = 288 K", 0.823, 0.25, height=10, color="red", tosys=1,
      justify="LH";
    */

    if( is_void(only_c3a) ){

      // Kunze et al. (2013):
      // S0: 1365 W/m2; solar constant values as given in the paper
      // BC: aquaplanet, present-day rotation rate, spectral irradiance
      //     from solar analogue
      // total pressure 1 bar in all simulations (M. Kunze, priv. comm.)
      // double-checked: 17.9.2013
      plmk, 3670.*1.e-6/1., 1046./1361., marker=5, msize=.6, color="blue";
      //      plt, "T = 264 K", 0.754, 0.0037, height=10, color="blue", tosys=1,
      //        justify="LH";
      plmk, 3670.*1.e-6/1., 1121./1361., marker=5, msize=.6, color="blue";
      //      plt, "T = 270 K", 0.826, 0.0037, height=10, color="blue", tosys=1,
      //        justify="LH";
      
      // Wolf & Toon (2013):
      // S0: solar constant value as given in the paper
      // total pressure 1.013 bar held constant
      // published in the paper
      // BC: present-day continents and rotation rate
      // double-checked: 17.9.2013
      plmk, 60000.*1.e-6*1.013, 1093.6/1361., marker=1, msize=.6, color="red";
      plmk, 20000.*1.e-6*1.013, 1093.6/1361., marker=1, msize=.6, color="blue";
      //      plt, "T = 272 K", 0.806, 0.021, height=10, color="blue", tosys=1,
      //        justify="LH";
      //      plt, "T = 288 K", 0.806, 0.06, height=10, color="red", tosys=1,
      //        justify="LH";
      
      // Charnay et al. (2013), no methane, modern cloud droplet size:
      // S0 = 1366 W/m2; solar constant values as given in the paper
      // mean surface pressure 1 bar, partial pressures as reported
      // in the paper
      // double-checked: 17.9.2013
      // 3.8 Ga:
      plmk, 0.01, 1025.1/1361., marker=2, msize=.6, color="blue";
      //      plt, "T = 256 K", 0.756, 0.01, height=10, color="blue", tosys=1,
      //        justify="LH";
      plmk, 0.1, 1025.1/1361., marker=2, msize=.6, color="red";
      //      plt, "T = 280 K", 0.756, 0.1, height=10, color="red", tosys=1,
      //        justify="LH";
      // 3.0 Ga:
      plmk, 0.01, 1081.9/1361., marker=2, msize=.6, color="blue";
      //      plt, "T = 269 K", 0.798, 0.01, height=10, color="blue", tosys=1,
      //        justify="LH";
      plmk, 0.1, 1081.9/1361., marker=2, msize=.6, color="red";
      //      plt, "T = 290 K", 0.798, 0.1, height=10, color="red", tosys=1,
      //        justify="LH";
      // 2.5 Ga:
      plmk, 0.01, 1120.8/1361., marker=2, msize=.6, color="blue";
      //      plt, "T = 271 K", 0.826, 0.01, height=10, color="blue", tosys=1,
      //        justify="LH";
      plmk, 0.1, 1120.8/1361., marker=2, msize=.6, color="red";
      //      plt, "T = 293 K", 0.826, 0.08, height=10, color="red", tosys=1,
      //        justify="LH";
      
      // Le Hir et al. (2013), modern cloud droplet size, 1.7e-6 CH4:
      // BC: realistic topography
      // S0 = ?;  solar constant values as given in the paper
      // double-checked: 17.9.2013
      plmk, 0.056, 1053./1361., marker=3, msize=.6, color="red";
      //      plt, "T = 289 K", 0.777, 0.056, height=10, color="red", tosys=1,
      //        justify="LH";
      plmk, 0.0252, 1053./1361., marker=3, msize=.6, color="blue", 
        width=3;
      //      plt, "T = 200 K", 0.777, 0.021, height=10, color="blue", tosys=1,
      //        justify="LH";

    }

  }
      
  logxy, 0, 1;
  limits, xl, xr, 1.5e-4, 2.;
  xytitles, "Solar luminosity relative to today", 
    "CO_2_ partial pressure  (bar)",
    [-0.02,0.01];
  topxtitle, "Time before present (Gyr)", offset=0.04;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  if( is_void(only_1d) & is_void(only_c3a) ){
    plegend, [4,5], ["Kienert et al. (2012)","Kunze et al. (2014)"], msize=.6, origin=[.1,.175];
    plegend, [2,3], ["Charnay et al. (2013)","Le Hir et al. (2014)"], msize=.6, origin=[.40,.175];
    plegend, [1], ["Wolf & Toon (2013)"], msize=.6, origin=[.7,.175];
  }
  if( is_void(only_1d) & !is_void(only_c3a) )
    plegend, [4], ["Kienert et al. (2012)"], msize=.6, origin=[.1,.175];
    



  if( is_void(only_1d) & is_void(only_c3a) ){
    pdf, "Plots/archean_co2_3d_synthesis_sfb";
    eps, "Plots/archean_co2_3d_synthesis_sfb";
    png, "Plots/archean_co2_3d_synthesis_sfb", dpi=600;
  }
  if( !is_void(only_1d) ){
    pdf, "Plots/archean_co2_1d_sfb";
    eps, "Plots/archean_co2_1d_sfb";
    png, "Plots/archean_co2_1d_sfb", dpi=600;
  }
  if( !is_void(only_c3a) ){
    pdf, "Plots/archean_co2_3d_sfb";
    eps, "Plots/archean_co2_3d_sfb";
    png, "Plots/archean_co2_3d_sfb", dpi=300;
  }
  
}


// 4.5.2021: copy of plot_glaciation_threshold_aqua from threshold.i
func plot_archean_co2_3d_synthesis_sfb2021( void )
{

  // define the plot limits on the x-axis (important for labels on top
  // of the plot!):
  xl = 0.73;
  xr = 0.85;

  // define color for proxy values:
  pcol = [125,125,125];

  // define half-width for arrow heads and error bars:
  dl = 0.0010;

  window, style="notsoflat.gs";
  fma;

  // Rye et al. (1995) upper limit:
  // 10^-1.4 atm = 0.0398 atm between 2.75 and 2.2 Ga 
  plg, .0398*[1,1], gough_age_to_L([2.75,2.2]), width=2, color=pcol;
  Lmid = (gough_age_to_L(2.75)+gough_age_to_L(2.2))/2.;
  plg, .0398*[.5,1], Lmid*[1.,1.], width=2, color=pcol;
  plg, .0398*[.5,.6], Lmid+[0.,dl], width=2, color=pcol;
  plg, .0398*[.6,.5], Lmid+[-dl,0.], width=2, color=pcol;
  plt, "R+95", Lmid, 0.0398*.375, height=8, tosys=1, color=pcol, justify="LH";
  

  // Hessler et al. (2004) lower limits:
  // age: 3.2 Ga corresponding to L/L0 = 0.78
  // lower limit at 25 deg C: 0.0025 bar
  plg, [0.0025,0.0025], 0.78+[-dl,dl], width=2, color=pcol; 
  plg, [0.0025,0.008], [0.78,0.78], width=2, color=pcol;
  plg, 0.008*[0.8,1.], 0.78+[-dl,0.], width=2, color=pcol;
  plg, 0.008*[0.8,1.], 0.78+[dl,0.], width=2, color=pcol;
  plt, "H04", 0.78, 0.00185, height=8, tosys=1, color=pcol, justify="CH";

  // Sheldon (2006) measurement:
  // age: 2.2 Ga corresponding to L/L0 = 0.84 
  // range: (23 /3 *3) PAL "PAL" is not defined, at some point in
  // the paper there is the conversion from 2.51e-3 bar to 6.8 PAL,
  // from which one can conclude that PAL = 370ppm:
  local a, c;
  read_columns, "../ArcheanClimate/Data/sheldon_2006.dat", 1,a, 2,c;
  l = gough_age_to_L( a );
  c *= 0.00037;
  //  for( n=1; n<=numberof(c); n++ ){
  for( n=1; n<=2; n++ ){
    plg, [c(n)/3.,c(n)*3.], l(n)+[0,0], width=2, color=pcol;
    plg, [c(n)/3.,c(n)/3.], l(n)+[-dl,dl], width=2, color=pcol;
    plg, [c(n)*3.,c(n)*3.], l(n)+[-dl,dl], width=2, color=pcol;
    plt, "S06", l(n), c(n)/4., height=8, tosys=1, color=pcol, justify="CH";
  }

  // Rosing et al. (2010) upper limit:
  // the upper limit of 0.0009 bar is for 25 deg C
  plg, 0.0009*[1.,1.], [0.775,0.833], width=2, color=pcol;
  plg, 0.0009*[1.,0.5], [0.804,0.804], width=2, color=pcol;
  plg, 0.0009*[0.5,0.6], 0.804+[0.,-dl], width=2, color=pcol;
  plg, 0.0009*[0.5,0.6], 0.804+[0.,dl], width=2, color=pcol;
  plt, "R+10", 0.804, 0.0009*.35, height=8, tosys=1, color=pcol, justify="CH";

  // Driese et al. (2011) measurement:
  // age: 2.69 Ga, corresponding to L/L0 = 0.813
  // best estimate: 41 times PAL
  // range: 10-50 times PAL; "PAL" is not defined, at some point in 
  // the paper there is the conversion from 0.009 bar to 25 PAL,
  // from which one can derive a value of PAL = 360ppm:
  //  plmk, 41.*0.00036, 0.813, marker=4, msize=.5, color=[255,165,0];
  plg, [10.,50.]*0.00036, 0.813+[0.,0.], width=2, color=pcol;
  plg, [10.,10.]*0.00036, 0.813+[-dl,dl], width=2, color=pcol;
  plg, [50.,50.]*0.00036, 0.813+[-dl,dl], width=2, color=pcol;
  plt, "D+11", 0.813, 0.00275, height=8, tosys=1, color=pcol, justify="CH";

  // Kanzaki & Murakami (2015) paleosol reconstruction:
  // Again, "PAL" is not defined in the paper, from Fig. 9 one can
  // deduce that PAL = 320ppm:
  // 2.77 Ga:
  plg, [85.,510.]*0.00032, gough_age_to_L(2.77)*[1,1], width=2, color=pcol;
  plg, [85.,85.]*0.00032, gough_age_to_L(2.77)+[-dl,+dl], width=2, color=pcol;
  plg, [85.,85.]*0.00032, gough_age_to_L(2.77)+[-dl,+dl], width=2, color=pcol;
  plg, [510.,510.]*0.00032, gough_age_to_L(2.77)+[-dl,+dl], width=2, color=pcol;
  plg, [510.,510.]*0.00032, gough_age_to_L(2.77)+[-dl,+dl], width=2, color=pcol;
  plt, "KM15",  gough_age_to_L(2.82), 510.*0.00032, height=8, tosys=1, color=pcol, justify="RC";
  // 2.75 Ga:
  plg, [78.,2500.]*0.00032, gough_age_to_L(2.75)*[1,1], width=2, color=pcol;
  plg, [78.,78.]*0.00032, gough_age_to_L(2.75)+[-dl,+dl], width=2, color=pcol;
  plg, [78.,78.]*0.00032, gough_age_to_L(2.75)+[-dl,+dl], width=2, color=pcol;
  plg, [2500.,2500.]*0.00032, gough_age_to_L(2.75)+[-dl,+dl], width=2, color=pcol;
  plg, [2500.,2500.]*0.00032, gough_age_to_L(2.75)+[-dl,+dl], width=2, color=pcol;
  plt, "KM15",  gough_age_to_L(2.7), 2500.*0.00032, height=8, tosys=1, color=pcol, justify="LC";
  // 2.46 Ga:
  plg, [160.,490.]*0.00032, gough_age_to_L(2.46)*[1,1], width=2, color=pcol;
  plg, [160.,160.]*0.00032, gough_age_to_L(2.46)+[-dl,+dl], width=2, color=pcol;
  plg, [160.,160.]*0.00032, gough_age_to_L(2.46)+[-dl,+dl], width=2, color=pcol;
  plg, [490.,490.]*0.00032, gough_age_to_L(2.46)+[-dl,+dl], width=2, color=pcol;
  plg, [490.,490.]*0.00032, gough_age_to_L(2.46)+[-dl,+dl], width=2, color=pcol;
  plt, "KM15",  gough_age_to_L(2.46), 490.*0.00032*1.5, height=8, tosys=1, color=pcol, justify="CH";
  // 2.15 Ga:
  plg, [30.,190.]*0.00032, gough_age_to_L(2.15)*[1,1], width=2, color=pcol;
  plg, [30.,30.]*0.00032, gough_age_to_L(2.15)+[-dl,+dl], width=2, color=pcol;
  plg, [30.,30.]*0.00032, gough_age_to_L(2.15)+[-dl,+dl], width=2, color=pcol;
  plg, [190.,190.]*0.00032, gough_age_to_L(2.15)+[-dl,+dl], width=2, color=pcol;
  plg, [190.,190.]*0.00032, gough_age_to_L(2.15)+[-dl,+dl], width=2, color=pcol;
  plt, "KM15",  gough_age_to_L(2.15), 190.*0.00032*1.5, height=8, tosys=1, color=pcol, justify="CH";
  // 2.08 Ga:
  plg, [20.,620.]*0.00032, gough_age_to_L(2.08)*[1,1], width=2, color=pcol;
  plg, [20.,20.]*0.00032, gough_age_to_L(2.08)+[-dl,+dl], width=2, color=pcol;
  plg, [20.,20.]*0.00032, gough_age_to_L(2.08)+[-dl,+dl], width=2, color=pcol;
  plg, [620.,620.]*0.00032, gough_age_to_L(2.08)+[-dl,+dl], width=2, color=pcol;
  plg, [620.,620.]*0.00032, gough_age_to_L(2.08)+[-dl,+dl], width=2, color=pcol;
  plt, "KM15",  gough_age_to_L(2.08), 620.*0.00032*1.5, height=8, tosys=1, color=pcol, justify="CH";
  /*
  // 1.85 Ga:
  plg, [23.,210.]*0.00032, gough_age_to_L(1.85)*[1,1], width=2, color=pcol;
  plg, [23.,23.]*0.00032, gough_age_to_L(1.85)+[-dl,+dl], width=2, color=pcol;
  plg, [23.,23.]*0.00032, gough_age_to_L(1.85)+[-dl,+dl], width=2, color=pcol;
  plg, [210.,210.]*0.00032, gough_age_to_L(1.85)+[-dl,+dl], width=2, color=pcol;
  plg, [210.,210.]*0.00032, gough_age_to_L(1.85)+[-dl,+dl], width=2, color=pcol;
  plt, "KM15",  gough_age_to_L(1.85), 210.*0.00032*1.5, height=8, tosys=1, color=pcol, justify="CH";
  */
                                                                    
  
  /*
  // Royer (2006) compilation:
  read_columns, "~/Climate/Data/royer2006co2.dat",
    1,aa, 4,cc;
  // throw away upper limits:
  nonzero = where( cc>0. );
  cc = cc(nonzero); aa = aa(nonzero);
  ss = sort(aa); // range: 0.1 Ma to 447 Ma
  cc = cc(ss); aa = aa(ss);
  plmk, cc/1.e6, gough_age_to_L( aa/1000. ), marker=1, msize=.1, color=pcol;
  //  plg, cc/1.e6, gough_age_to_L( aa/1000. ), width=1, color=pcol;
  // OK, we need a binned version of this: interp() does not work, 10
  // Myr intervals aren't great either; let's try an n-point running
  // mean:
  np = 9;
  ns = int(floor(np/2.));
  aaa = ccc = [];
  for( n=ns+1; n<numberof(aa)-ns; n+=1 ){
    grow, ccc, avg(cc(n-ns:n+ns));
    grow, aaa, avg(aa(n-ns:n+ns));
  }
  plg, ccc/1.e6, gough_age_to_L( aaa/1000. ), width=2, color=pcol;
  */

  /*
  // Foster et al. (2017) compilation:
  read_columns, "~/Climate/Data/Foster2017_allData.dat",
    1,aa, 2,cc;
  plmk, cc/1.e6, gough_age_to_L( aa/1000. ), marker=5, msize=.1, color=[200,200,200];
  read_columns, "~/Climate/Data/Foster2017_Fit2.dat",
    1,aa, 2,cc, 3,cc_low, 4,cc_high;
  plg, cc/1.e6, gough_age_to_L( aa/1000. ), width=2, color=pcol;
  //  plg, cc_low/1.e6, gough_age_to_L( aa/1000. ), width=1, color=pcol;
  //  plg, cc_high/1.e6, gough_age_to_L( aa/1000. ), width=1, color=pcol;
  
  // modern value:
  plmk, 415./1.e6, 1., marker=5, msize=.4, color=pcol;
  //  plmk, 400./1.e6, 1., marker=1, msize=.3, color=pcol;
  */


  // mark important ages on top of the plot:
  s = array( 0, [2,1,1] );
  //  pli, bytscl( s, cmin=0, cmax=1),
  //    gough_age_to_L(1.0), 0.5, gough_age_to_L(0.542), 1.0;
  ages = [4.0,3.5,3.0,2.5,2.0];
  //  nages = ["3.8","2.5","0.5","0.0"];
  nages = ["4.0","3.5","3.0","2.5","2.0"];
  // convert this into relative solar luminosities:
  lages = gough_age_to_L( ages );
  pldj, lages, array( 1./1.356, numberof(ages) ), lages, array( 1., numberof(ages) );
  for( n=1; n<=numberof(ages); n++ )
    // viewport= { 0.14, 0.75, 0.45, 0.90 }
    plt, nages(n), 0.14+(lages(n)-xl)/(xr-xl)*(0.75-0.14), 0.905, 
      tosys=0, height=18, justify="CB";
  plg, [1.,1.], [xl,xr];
  ages = [3.8,2.5,0.542,0.];
  lages = gough_age_to_L( ages );
  pldj, lages, array( 1.99, 4 ), lages, array( 1., 4 );
  plt, "Hadean", 0.74, 1.445, tosys=1, height=12, justify="CH";
  plt, "Archean", (lages(1)+lages(2))/2., 1.445, 
    tosys=1, height=12, justify="CH";
  plt, "Proterozoic", 0.835, 1.445, tosys=1, height=12, justify="CH";
  //  plt, "Phanerozoic", (lages(3)+lages(4))/2., 1.445, 
  //    tosys=1, height=12, justify="CH";
  //  plt, "Future", (lages(4)+lages(5))/2., 1.4, 
  //    tosys=1, height=12, justify="CH";

  /*
  ages = [2.5,1.6,1.0,0.542];
  // convert this into relative solar luminosities:
  lages = gough_age_to_L( ages );
  pldj, lages, array( 0.5, 4 ), lages, array( 1., 4 );
  plg, [0.5,0.5], [lages(1),lages(0)];
  plt, "Paleoproterozoic", (lages(1)+lages(2))/2., 0.72, 
    tosys=1, height=12, justify="CH";
  plt, "Mesoprot.", (lages(2)+lages(3))/2., 0.72, 
    tosys=1, height=12, justify="CH";
  plt, "Neoprot.", (lages(3)+lages(4))/2., 0.72, 
    tosys=1, height=12, justify="CH", font="helveticaB";
  */

  // plot aquaplanet simulations:
  read_columns, "../GlaciationThreshold/snowball_bifurcation_aquaplanet_new_corrected.dat",
    1,a_aqua, 2,l_aqua, 3,c_aqua_low, 4,c_aqua_high;
  // compute most likely critical CO2:
  c_aqua = .5*(c_aqua_low+c_aqua_high);
  plmk, c_aqua/1.e6, l_aqua/1361., marker=4, msize=.6, width=2, color="blue";
  /*
  pldj,  l_aqua/1361., c_aqua_low/1.e6,  l_aqua/1361., c_aqua_high/1.e6,
    width=3, color="black";
  pldj,  l_aqua/1361.-dl, c_aqua_low/1.e6,  l_aqua/1361.+dl, c_aqua_low/1.e6,
    width=3, color="black";
  pldj,  l_aqua/1361.-dl, c_aqua_high/1.e6,  l_aqua/1361.+dl, c_aqua_high/1.e6,
    width=3, color="black";
  */


  // plot von Paris et al. model results:
  local l, pco2;
  read_columns, "Data/CO2_Lsun_273K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=3, color=[125,125,255];
  plt, "T = 273 K (1D model)", 0.733, .03, height=10, tosys=1, 
    justify="LH", color=[125,125,255];

  
  // plot selected 3D model results for critical CO2:

  // ARCHEAN:

  // Kienert et al. (2012):
  // compute partial pressure, the quoted values are surface pressures
  // in the absence of any other gas; note that p_IN2 = 0.8 bar:
  p_ICO2 = [0.4,0.25,0.13];
  //  p_CO2  = (p_ICO2/44.)/(p_ICO2/44.+0.8/28.)*(0.8+p_ICO2);
  p_CO2  = p_ICO2/(0.8+p_ICO2);
  plmk, p_CO2, [0.7525,0.79,0.82], marker=4, msize=.6, color="blue";
  plt, "K+12", 0.7525, p_CO2(1)/1.75, height=8, tosys=1, justify="CH", color="blue";
  plt, "K+12", 0.7900, p_CO2(2)/1.75, height=8, tosys=1, justify="CH", color="blue";
  plt, "K+12", 0.8200, p_CO2(3)/1.75, height=8, tosys=1, justify="CH", color="blue";

  // Charnay et al. (2013), no methane, modern cloud droplet size:
  // S0 = 1366 W/m2; solar constant values as given in the paper
  // mean surface pressure 1 bar, partial pressures as reported
  // in the paper
  // double-checked: 17.9.2013, corrected: 10.11.2020
  // 3.8 Ga:
  plg, [0.0009,0.01], 1025.1/1361.*[1.,1.], width=2, color="blue";
  plg, 0.0009*[1,1], 1025.1/1361.+[-dl,+dl], width=2, color="blue";
  plg, 0.01*[1,1], 1025.1/1361.+[-dl,+dl], width=2, color="blue";
  plmk, .5*(0.0009+0.01), 1025.1/1361., marker=3, msize=.6, color="blue";
  plt, "C+13", 1025.1/1361., 0.0009/1.5, height=8, tosys=1, justify="CH", color="blue";
  // 3.0 Ga:
  plmk, 0.0009, 1081.9/1361., marker=3, msize=.6, color="blue";
  plg, 0.0009*[1.,.5],     1081.9/1361.*[1.,1.], width=2, color="blue";
  plg, 0.0009*.5*[1.2,1.], 1081.9/1361.+[-dl,0.], width=2, color="blue";
  plg, 0.0009*.5*[1.2,1.], 1081.9/1361.+[+dl,0.], width=2, color="blue";
  plt, "C+13", 1081.9/1361, 0.0009*.35, height=8, tosys=1, justify="CH", color="blue";
  // 2.5 Ga:
  plmk, 0.0009, 1120.8/1361+0.0005, marker=3, msize=.6, color="blue";
  plg, 0.0009*[1.,.5],     (1120.8/1361.+0.0005)*[1.,1.], width=2, color="blue";
  plg, 0.0009*.5*[1.2,1.], (1120.8/1361.+0.0005)+[-dl,0.], width=2, color="blue";
  plg, 0.0009*.5*[1.2,1.], (1120.8/1361.+0.0005)+[+dl,0.], width=2, color="blue";
  plt, "C+13", 1120.8/1361.+0.0005, 0.0009*.35, height=8, tosys=1, justify="CH", color="blue";

  
  // Wolf & Toon (2013):
  // S0: solar constant value as given in the paper
  // total pressure 1.013 bar held constant
  // published in the paper
  // BC: present-day continents and rotation rate
  // double-checked: 17.9.2013, corrected: 28.10.2020
  plmk, 5.e-3*1.013, 1093.6/1361., marker=3, msize=.6, color="blue";
  plg, 5.e-3*1.013*[1.,.5],     1093.6/1361.*[1.,1.], width=2, color="blue";
  plg, 5.e-3*1.013*.5*[1.2,1.], 1093.6/1361.+[-dl,0.], width=2, color="blue";
  plg, 5.e-3*1.013*.5*[1.2,1.], 1093.6/1361.+[+dl,0.], width=2, color="blue";
  plt, "WT13", 1093.6/1361., 0.00165, height=8, tosys=1, justify="CH", color="blue";

  // Kunze et al. (2014):
  // S0: 1365 W/m2; solar constant values as given in the paper
  // BC: aquaplanet, present-day rotation rate, spectral irradiance
  //     from solar analogue, no information on CH4, assuming 0 ppb
  // total pressure 1 bar in all simulations (M. Kunze, priv. comm.)
  // double-checked: 17.9.2013, corrected: 28.10.2020
  plmk, 3670.*1.e-6/1., 1046./1361., marker=3, msize=.6, color="blue";
  plg, 3670.*1.e-6/1.*[1.,.5], 1046./1361.*[1.,1.], width=2, color="blue";
  plg, 3670.*1.e-6/1.*.5*[1.2,1.], 1046./1361.+[-dl,0.], width=2, color="blue";
  plg, 3670.*1.e-6/1.*.5*[1.2,1.], 1046./1361.+[+dl,0.], width=2, color="blue";
  plmk, (3670.+367.)/2.*1.e-6/1., 1121./1361.-0.0005, marker=3, msize=.6, color="blue";
  plg, [367.,3670.]*1.e-6/1., (1121./1361.-0.0005)*[1.,1.], width=2, color="blue";
  plg, 367.0/1.e6*[1,1], (1121./1361.-0.0005)+[-dl,+dl], width=2, color="blue";
  plg, 3670./1.e6*[1,1], (1121./1361.-0.0005)+[-dl,+dl], width=2, color="blue";
  plt, "K+14", 1046./1361., 0.0012, height=8, tosys=1, justify="CH", color="blue";
  plt, "K+14", 1121./1361.-0.0005, 0.00023, height=8, tosys=1, justify="CH", color="blue";

  // Le Hir et al. (2013), modern cloud droplet size, 1.7e-6 CH4:
  // BC: realistic topography
  // S0 = ?;  solar constant values as given in the paper
  // 3.5 Ga, pCH4=1.7e-6 bar = 1700 ppb, pCO2=0.0252 bar (snowball), 0.0560 bar (warm)
  // double-checked: 17.9.2013, corrected: 10.11.2020
  // total forcing:
  forc = co2_c2f_old( [25200.,56000.] ) + ch4_c2f_old( 1700. );
  // CO2 equivalent:
  co2e = co2_f2c_old( forc );
  plg, co2e/1.e6, 1053./1361.*[1,1], width=3, color="white";
  plg, co2e(1)/1.e6*[1,1], 1053./1361.+[-dl,+dl], width=3, color="white";
  plg, co2e(2)/1.e6*[1,1], 1053./1361.+[-dl,+dl], width=3, color="white";
  plmk, co2e(avg)/1.e6, 1053./1361., marker=3, msize=.65, color="white";
  plg, co2e/1.e6, 1053./1361.*[1,1], width=2, color="blue";
  plg, co2e(1)/1.e6*[1,1], 1053./1361.+[-dl,+dl], width=2, color="blue";
  plg, co2e(2)/1.e6*[1,1], 1053./1361.+[-dl,+dl], width=2, color="blue";
  plmk, co2e(avg)/1.e6, 1053./1361., marker=3, msize=.6, color="blue";
  plt, "L+14", 1053./1361., 1.75e-2, height=8, tosys=1, justify="CH", color="blue";


  // PALEOPROTEROZOIC:
  
  // Teitler et al. (2014): AGCM, mixed-layer ocean, diffusive heat transport,
  // no sea-ice dynamics
  // BC: solar constant 1100 W/m2, reconstructed paleogeography, 18 hours daylength,
  //     higher salinity (freezing point at -3.3 deg. C), 1 bar total pressure
  // open water at 5.5e-3 bar CO2 + 60 ppmv CH4
  // snowball   at 4.0e-3 bar CO2 + 60 ppmv CH4
  // total forcing:
  forc = co2_c2f_old( [4000.,5500.] ) +
    ch4_c2f_old( 60000. );
  // CO2 equivalent:
  co2e = co2_f2c_old( forc );
  
  plmk, avg(co2e)/1.e6, 1100./1361., marker=3, msize=.65, color="white";
  plg, co2e/1.e6, 1100./1361.*[1,1], width=3, color="white";
  plg, co2e(1)/1.e6*[1,1], 1100./1361.+[-dl,+dl], width=3, color="white";
  plg, co2e(2)/1.e6*[1,1], 1100./1361.+[-dl,+dl], width=3, color="white";
  plmk, avg(co2e)/1.e6, 1100./1361., marker=3, msize=.6, color="blue";
  plg, co2e/1.e6, 1100./1361.*[1,1], width=2, color="blue";
  plg, co2e(1)/1.e6*[1,1], 1100./1361.+[-dl,+dl], width=2, color="blue";
  plg, co2e(2)/1.e6*[1,1], 1100./1361.+[-dl,+dl], width=2, color="blue";
  plt, "T+14", 1100./1361., 0.009, height=8, tosys=1, justify="CH", color="blue";


  /*
  // MESOROTEROZOIC:

  // Fiorella & Sheldon (2017):
  // AOGCM (CESM), 1.0 Ga
  // S0 "reduced by 9%", present-day S0 1367 W/m2, value used in the simulations
  // is 1244 W/m2 (R. Fiorella, priv. comm.)
  // without CH4, snowball at 280 ppm CO2, no snowball at 1400 ppm
  plg, [280.,1400.]/1.e6, 1244.*[1,1]/1361., width=2, color="black";
  plg, 280.0/1.e6*[1,1],  1244./1361.+[-dl,+dl], width=2, color="black";
  plg, 1400./1.e6*[1,1],  1244./1361.+[-dl,+dl], width=2, color="black";
  plmk, 0.5*(280.+1440.)/1.e6, 1244./1361., marker=1, msize=.4, color="black";
  plt, "FS17", 1244./1361., 0.0025, height=8, tosys=1, justify="CH";


  
  // NEOPROTEROZOIC:

  // Chandler & Sohl (2000): AGCM, solar constant 1285 W/m2,
  // continental configuration for 600 Ma, snowball bifurcation below
  // 40 ppm:
  plmk, 40./1.e6, 1285./1361., marker=3, msize=.4, color="black";
  plg, 40./1.e6*[1.,.5],     1285./1361.*[1.,1.], width=2, color="black";
  plg, 40./1.e6*.5*[1.2,1.], 1285./1361.+[-dl,0.], width=2, color="black";
  plg, 40./1.e6*.5*[1.2,1.], 1285./1361.+[+dl,0.], width=2, color="black";
  //  plt, "CS00", 0.94, 40./1.e6, height=8, tosys=1, justify="RH";
  plt, "CS00", 1285./1361., 1.5e-5, height=8, tosys=1, justify="CH";
  
  // Poulsen et al. (2002): AOGCM (FOAM), solar constant 93% of
  // (presumably) 1365 W/m2, continental configuration for 545 Ma,
  // simulations with 140 ppm of CO2 and 1714 ppb of CH4, no
  // glaciation, so this is an upper limit:
  // total forcing:
  forc = co2_c2f_old( 140. ) +
    ch4_c2f_old( 1714. );  
  // CO2 equivalent:
  co2e = co2_f2c( forc );
  plmk, co2e/1.e6, 0.93*1365./1361., marker=1, msize=.4, color="black";
  plg, co2e/1.e6*[1.,.5],     0.93*1365./1361.*[1.,1.], width=2, color="black";
  plg, co2e/1.e6*.5*[1.2,1.], 0.93*1365./1361.+[-dl,0.], width=2, color="black";
  plg, co2e/1.e6*.5*[1.2,1.], 0.93*1365./1361.+[+dl,0.], width=2, color="black";
  plt, "P+02", 0.93*1365./1361., 0.00035, height=8, tosys=1, justify="CH";
  
  // Voigt et al. (2011): AOGCM, solar constant 1285 W/m2, Marinoan,
  // CH4 at 650 ppb, N2O at 270 ppb, bifurcation somewhere between 286
  // and 572 ppm:
  // total forcing:
  forc = co2_c2f( 286., 270., n0=270. ) +
    n2o_c2f( 270., 1.5*286., 650., n0=270., m0=650. ) +
    ch4_c2f( 650., 270., m0=650., n0=270. );
  // CO2 equivalent:
  co2e = co2_f2c( forc );
  plmk, co2e*1.5/1.e6, 1285./1361., marker=1, msize=.4, color="black";
  plg, [1.,2.]*co2e/1.e6, [1285./1361.,1285./1361.], width=2, color="black";
  plg, co2e/1.e6*[1,1], 1285./1361.+[-dl,+dl], width=2, color="black";
  plg, co2e/1.e6*[2,2], 1285./1361.+[-dl,+dl], width=2, color="black";
  //  plt, "V+11", 1285./1361., 7.e-4, height=8, tosys=1, justify="CH";
  plg, co2e*1.5/1.e6*[1,1], [0.947,0.949], width=1;
  plt, "V+11", 0.95, co2e*1.5/1.e6, height=8, tosys=1, justify="LH";

  // Liu et al. (2013): solar constant 0.94*1367 W/m2, CH4 at 805.6
  // ppb, N2O at 276.7 ppb, two continental configurations at the same
  // solar constant, bifurcation between 80-90 ppm and 140-150 ppm,
  // respectively:
  forc1 = co2_c2f_old( 80. ) +
    ch4_c2f_old( 805.6 );
  forc2 = co2_c2f_old( 150. ) +
    ch4_c2f_old( 805.6 );
  // CO2 equivalent:
  co2e1 = co2_f2c_old( forc, a=5.36, c0=80. );
  co2e2 = co2_f2c_old( forc, a=5.36, c0=150. );
  plg, [co2e1,co2e2]/1.e6, [1,1]*1285./1361, width=3, color="white";
  plg, [co2e1,co2e1]/1.e6, 1285./1361.+[-dl,dl], width=3, color="white";
  plg, [co2e2,co2e2]/1.e6, 1285./1361.+[-dl,dl], width=3, color="white";
  plmk, (co2e1+co2e2)/2./1.e6, 1285./1361., marker=1, msize=.45, color="white";
  plmk, (co2e1+co2e2)/2./1.e6, 1285./1361., marker=1, msize=.4, color="black";
  plg, [co2e1,co2e2]/1.e6, [1,1]*1285./1361, width=2, color="black";
  plg, [co2e1,co2e1]/1.e6, 1285./1361.+[-dl,dl], width=2, color="black";
  plg, [co2e2,co2e2]/1.e6, 1285./1361.+[-dl,dl], width=2, color="black";
  plt, "L+13", 1285./1361., 6.5e-5, height=8, tosys=1, justify="CH";

  // Feulner & Kienert (2014):
  plmk, 105./1.e6, 1283./1361., marker=4, msize=.45, color="white";
  plmk, 105./1.e6, 1283./1361., marker=4, msize=.4, color="black";
  plg, [100.,110.]/1.e6, [1,1]* 1283./1361., width=2;
  plmk, 125./1.e6, 1290./1361., marker=4, msize=.4, color="black";
  plg, [120.,130.]/1.e6, [1,1]* 1290./1361., width=2;
  plt, "FK14", (1283.+1290.)/(2.*1361.), 1.9e-4, height=8, tosys=1, justify="CH";

  // Feulner, Hallmann & Kienert (2015):
  //  plmk,  15./1.e6, 1283./1361., marker=4, msize=.4, width=1;
  //  plmk,  15./1.e6, 1283./1361., marker=4, msize=.3, color=[150,255,255];
  //  plt, "F+15", 1283./1361., 9.e-6, height=8, tosys=1, justify="CH";
  
  // Liu et al. (2017): AOGCM (CCSM3) with ice-sheets, continental
  // configurations for 720 and 570 Ma, but same value for solar
  // constant, 94% of present-day value (1285 W/m2, explicitly given
  // in the paper), CH4 at 805.6 ppb, N2O at 276.7 ppb (as in Liu et
  // al. 2013), snowball bifurcation between 630 and 600 ppm for 720
  // Ma and between 320 and 300 ppm for 570 Ma:
  forc1 = co2_c2f_old( 300. ) +
    ch4_c2f_old( 805.6 );
  forc2 = co2_c2f_old( 630. ) +
    ch4_c2f_old( 805.6 );
  // CO2 equivalent:
  co2e1 = co2_f2c_old( forc, a=5.36, c0=300. );
  co2e2 = co2_f2c_old( forc, a=5.36, c0=630. );
  plg, [co2e1,co2e2]/1.e6, [1,1]*1285./1361, width=3, color="white";
  plg, [co2e1,co2e1]/1.e6, 1285./1361.+[-dl,dl], width=3, color="white";
  plg, [co2e2,co2e2]/1.e6, 1285./1361.+[-dl,dl], width=3, color="white";
  plmk, (co2e1+co2e2)/2./1.e6, 1285./1361., marker=1, msize=.45, color="white";
  plmk, (co2e1+co2e2)/2./1.e6, 1285./1361., marker=1, msize=.4, color="black";
  plg, [co2e1,co2e2]/1.e6, [1,1]*1285./1361, width=2, color="black";
  plg, [co2e1,co2e1]/1.e6, 1285./1361.+[-dl,dl], width=2, color="black";
  plg, [co2e2,co2e2]/1.e6, 1285./1361.+[-dl,dl], width=2, color="black";
  plg, (co2e1+co2e2)/2./1.e6*[1,1], [0.940,0.942], width=1;
  plt, "L+17", 0.94, (co2e1+co2e2)/2./1.e6, height=8, tosys=1, justify="RH";
  

  
  
  // CARBONIFEROUS/PERMIAN: Feulner (2017): solar constant 1327 W/m2,
  // bifurcation between 40 and 35 ppm:
  plmk, 37.5/1.e6, 1327./1361., marker=4, msize=.4, color="black";
  plg, [35,40]/1.e6, [1,1]*1327./1361, width=2, color="black";
  plt, "F17", 1327./1361., 2.1e-5, height=8, tosys=1, justify="CH";


  
  // MODERN:
  
  // Yang et al. (2012a): AOGCM (CCSM3), modern snowballs, solar
  // constant 1367 W/m2, CH4 at 805.6 ppb, N2O at 276.7 ppb, snowball
  // bifurcation between 20 ppm and 17.5 ppm:  
  // total forcing:
  forc = co2_c2f_old( 18.75 ) +
    ch4_c2f_old( 805.6 );
  // CO2 equivalent:
  co2e = co2_f2c_old( forc );
  plmk, co2e/1.e6, 1367./1361., marker=1, msize=.4, color="black";
  plt, "Y+12a", 1367./1361., 1.1e-5, height=8, tosys=1, justify="CH";

  // Yang et al. (2012c): AOGCM (CCSM4), modern snowballs, solar
  // constant 1367 W/m2, CH4 at 805.6 ppb, N2O at 276.7 ppb, snowball
  // bifurcation between 100 ppm and 70 ppm:
  // total forcing:
  forc = co2_c2f_old( 85. ) +
    ch4_c2f_old( 805.6 );
  // CO2 equivalent:
  co2e = co2_f2c_old( forc );
  plmk, co2e/1.e6, 1367./1361., marker=1, msize=.4, color="black";
  plg, [70.,100.]/1.e6, 1367./1361.*[1,1], width=2, color="black";
  plg, 70./1.e6*[1,1], 1367./1361.+[-dl,+dl], width=2, color="black";
  plg, 100./1.e6*[1,1], 1367./1361.+[-dl,+dl], width=2, color="black";
  plt, "Y+12c", 1367./1361., 5.e-5, height=8, tosys=1, justify="CH";

  */

  // PLOT LEGENDS, LIMITS, TITLES AND FILE OUTPUT: 
  logxy, 0, 1;
  limits, xl, xr, 5.e-5, 1.99;
  xytitles, "Solar luminosity relative to today", 
    "CO_2_ partial pressure  (bar)",
    [-0.02,0.01];
  topxtitle, "Time before present (Ga)", offset=0.04;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  plegend, [4,3],
    ["OGCM","AGCM"],
    msize=.6, color="blue",
    origin=[.075,.175];

  filename = "Plots/archean_co2_3d_sfb2021";
  pdf, filename;
  eps, filename;
  png, filename, dpi=300;
  
}



// modified copy of the "review version" plot_archean_co2
func plot_archean_co2_3d_synthesis_habil( void )
{

  // define the plot limits on the x-axis (important for labels on top
  // of the plot!):
  xl = 0.73;
  xr = 0.85;

  window, style="notsoflat.gs";
  fma;

  // mark important ages on top of the plot:
  ages = [3.8,2.5];
  nages = ["3.8","2.5"];
  // convert this into relative solar luminosities:
  lages = gough_age_to_L( ages );
  pldj, lages, array( 2., 4 ), lages, array( 1.5, 4 );
  for( n=1; n<=numberof(ages); n++ )
    // viewport= { 0.14, 0.75, 0.45, 0.90 }
    plt, nages(n), 0.14+(lages(n)-xl)/(xr-xl)*(0.75-0.14), 0.905, 
      tosys=0, height=18, justify="CB";

  // shade model result regions for the two different classes:
  shade_area, 0.73, 0.85, 0.115, 0.68, level=0.8;
  plt, "OGCM, sea-ice dynamics, simplified atmosphere", 0.79, 1.,
    height=12, tosys=1, justify="CH";
  shade_area, 0.73, 0.85, 0.0032, 0.115, level=0.9;
  plt, "AGCM, mixed-layer ocean, prescribed heat transport, no sea-ice dynamics", 0.79, 0.0018, height=12, tosys=1, justify="CH";
  palette, "gray.gp";


  // plot von Paris et al. model results:
  local l, pco2;
  read_columns, "Data/CO2_Lsun_288K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=3, color=[255,125,125];
  read_columns, "Data/CO2_Lsun_273K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=3, color=[125,125,255];
  if( is_void(nature) ){
    plt, "T = 288 K (1D model)", 0.733, .165, height=12, tosys=1, 
      justify="LH", color=[255,125,125];
    plt, "T = 273 K (1D model)", 0.733, .03, height=12, tosys=1, 
      justify="LH", color=[125,125,255];
  }
  else{
    plt, "T = 288 K (1D model, ref. 7)", 0.735, .145, height=14, tosys=1, justify="LH", color="red";
    plt, "T = 273 K (1D model, ref. 7)", 0.735, .022, height=14, tosys=1, justify="LH", color="blue";
  }

  // Kienert et al. (2012):
  // S0: 1361 W/m2, factors as used in the simulations:
  // BC: realistic topographies, higher rotation rates
  // double-checked: 17.9.2013
  // TODO: check definition of partial pressure
  plmk, [0.4,0.25,0.13], [0.7525,0.79,0.82], marker=4, msize=.6, 
    color="blue";
  plt, "T = 268 K", 0.756, 0.4, height=10, color="blue", tosys=1,
    justify="LH";
  plt, "T = 272 K", 0.793, 0.25, height=10, color="blue", tosys=1,
    justify="LH";
  plt, "T = 270 K", 0.823, 0.13, height=10, color="blue", tosys=1,
    justify="LH";
  plmk, [0.6,0.4,0.25], [0.7525,0.79,0.82], marker=4, msize=.6, 
    color="red";
  plt, "T = 289 K", 0.756, 0.6, height=10, color="red", tosys=1,
    justify="LH";
  plt, "T = 290 K", 0.793, 0.4, height=10, color="red", tosys=1,
    justify="LH";
  plt, "T = 288 K", 0.823, 0.25, height=10, color="red", tosys=1,
    justify="LH";
  // plot arrows indicating test simulations:
  plg, [0.40,0.15],   [0.7525,0.7525], color="blue", width=1;
  plg, [0.19,0.15],  [0.7515,0.7525], color="blue", width=1;
  plg, [0.19,0.15],  [0.7535,0.7525], color="blue", width=1;
  plg, [0.25,0.09375], [0.79,0.79], color="blue", width=1;
  plg, [0.1175,0.09375], [0.789,0.79], color="blue", width=1;
  plg, [0.1175,0.09375], [0.791,0.79], color="blue", width=1;
  plg, [0.13,0.04875], [0.82,0.82], color="blue", width=1;
  plg, [0.06,0.04875], [0.819,0.82], color="blue", width=1;
  plg, [0.06,0.04875], [0.821,0.82], color="blue", width=1;


  // Kunze et al. (2013):
  // S0: 1365 W/m2; solar constant values as given in the paper
  // BC: aquaplanet, present-day rotation rate, spectral irradiance
  //     from solar analogue
  // total pressure 1 bar in all simulations (M. Kunze, priv. comm.)
  // double-checked: 17.9.2013
  plmk, 3670.*1.e-6/1., 1046./1361., marker=5, msize=.4, color="blue";
  plt, "T = 264 K", 0.754, 0.0037, height=10, color="blue", tosys=1,
    justify="LH";
  plmk, 3670.*1.e-6/1., 1121./1361., marker=5, msize=.4, color="blue";
  plt, "T = 270 K", 0.826, 0.0037, height=10, color="blue", tosys=1,
    justify="LH";
  
  // Wolf & Toon (2013):
  // S0: solar constant value as given in the paper
  // total pressure 1.013 bar held constant
  // published in the paper
  // BC: present-day continents and rotation rate
  // double-checked: 17.9.2013
  plmk, 60000.*1.e-6*1.013, 1093.6/1361., marker=1, msize=.4, color="red";
  plmk, 20000.*1.e-6*1.013, 1093.6/1361., marker=1, msize=.4, color="blue";
  plt, "T = 272 K", 0.806, 0.021, height=10, color="blue", tosys=1,
    justify="LH";
  plt, "T = 288 K", 0.806, 0.06, height=10, color="red", tosys=1,
    justify="LH";
  
  // Charnay et al. (2013), no methane, modern cloud droplet size:
  // S0 = 1366 W/m2; solar constant values as given in the paper
  // mean surface pressure 1 bar, partial pressures as reported
  // in the paper
  // double-checked: 17.9.2013
  // 3.8 Ga:
  plmk, 0.01, 1025.1/1361., marker=2, msize=.4, color="blue";
  plt, "T = 256 K", 0.756, 0.01, height=10, color="blue", tosys=1,
    justify="LH";
  plmk, 0.1, 1025.1/1361., marker=2, msize=.4, color="red";
  plt, "T = 280 K", 0.756, 0.1, height=10, color="red", tosys=1,
    justify="LH";
  // 3.0 Ga:
  plmk, 0.01, 1081.9/1361., marker=2, msize=.4, color="blue";
  plt, "T = 269 K", 0.798, 0.01, height=10, color="blue", tosys=1,
    justify="LH";
  plmk, 0.1, 1081.9/1361., marker=2, msize=.4, color="red";
  plt, "T = 290 K", 0.798, 0.1, height=10, color="red", tosys=1,
    justify="LH";
  // 2.5 Ga:
  plmk, 0.01, 1120.8/1361., marker=2, msize=.4, color="blue";
  plt, "T = 271 K", 0.826, 0.01, height=10, color="blue", tosys=1,
    justify="LH";
  plmk, 0.1, 1120.8/1361., marker=2, msize=.4, color="red";
  plt, "T = 293 K", 0.826, 0.08, height=10, color="red", tosys=1,
    justify="LH";
  
  // Le Hir et al. (2013), modern cloud droplet size, 1.7e-6 CH4:
  // BC: realistic topography
  // S0 = ?;  solar constant values as given in the paper
  // double-checked: 17.9.2013
  plmk, 0.056, 1053./1361., marker=3, msize=.4, color="red";
  plt, "T = 289 K", 0.777, 0.056, height=10, color="red", tosys=1,
    justify="LH";
  plmk, 0.0252, 1053./1361., marker=3, msize=.4, color="blue";
  plt, "T = 200 K", 0.777, 0.021, height=10, color="blue", tosys=1,
    justify="LH";

      
  logxy, 0, 1;
  limits, xl, xr, 1.5e-4, 2.;
  xytitles, "Solar luminosity relative to today", 
    "CO_2_ partial pressure  (bar)",
    [-0.02,0.01];
  topxtitle, "Time before present (Ga)", offset=0.04;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  plegend, [4], ["Kienert et al. (2012)"], msize=.6, origin=[.1,.175];
  plegend, [2,3], ["Charnay et al. (2013)","Le Hir et al. (2014)"], msize=.4, origin=[.40,.175];
  plegend, [1,5], ["Wolf & Toon (2013)","Kunze et al. (2014)"], msize=.4, origin=[.7,.175];
    
  pdf, "Plots/archean_co2_3d_synthesis_habil";
  eps, "Plots/archean_co2_3d_synthesis_habil";
  png, "Plots/archean_co2_3d_synthesis_habil", dpi=300;
  
}

func plot_archean_co2_3d_synthesis_moritz( void )
{

  // define the plot limits on the x-axis (important for labels on top
  // of the plot!):
  xl = 0.73;
  xr = 0.85;

  window, style="notsoflat.gs";
  fma;

  // mark important ages on top of the plot:
  ages = [3.8,2.5];
  nages = ["3.8","2.5"];
  // convert this into relative solar luminosities:
  lages = gough_age_to_L( ages );
  pldj, lages, array( 2., 4 ), lages, array( 1.5, 4 );
  for( n=1; n<=numberof(ages); n++ )
    // viewport= { 0.14, 0.75, 0.45, 0.90 }
    plt, nages(n), 0.14+(lages(n)-xl)/(xr-xl)*(0.75-0.14), 0.905, 
      tosys=0, height=18, justify="CB";

  // shade model result regions for the two different classes:
  shade_area, 0.73, 0.85, 0.105, 0.5, level=0.8;
  plt, "OGCM, simplified atmosphere", 0.79, .8,
    height=12, tosys=1, justify="CH";
  shade_area, 0.73, 0.85, 0.003, 0.0325, level=0.9;
  plt, "AGCM, mixed-layer ocean, prescribed heat transport", 0.79, 0.0018, height=12, tosys=1, justify="CH";
  palette, "gray.gp";


  // plot von Paris et al. model results:
  local l, pco2;
  read_columns, "Data/CO2_Lsun_273K.dat", 1,l, 2,pco2;
  plg, pco2, l, width=3, color=[125,125,255];
  plt, "1D model", 0.75, .075, height=12, tosys=1, 
    justify="LH", color=[125,125,255];

  // Kienert et al. (2012):
  // S0: 1361 W/m2, factors as used in the simulations:
  // BC: realistic topographies, higher rotation rates
  // double-checked: 17.9.2013
  // TODO: check definition of partial pressure
  plmk, [0.4,0.25,0.13], [0.7525,0.79,0.82], marker=4, msize=.6, 
    color="blue";

  // Kunze et al. (2013):
  // S0: 1365 W/m2; solar constant values as given in the paper
  // BC: aquaplanet, present-day rotation rate, spectral irradiance
  //     from solar analogue
  // total pressure 1 bar in all simulations (M. Kunze, priv. comm.)
  // double-checked: 17.9.2013
  plmk, 3670.*1.e-6/1., 1046./1361., marker=5, msize=.4, color="blue";
  plmk, 3670.*1.e-6/1., 1121./1361., marker=5, msize=.4, color="blue";
  
  // Wolf & Toon (2013):
  // S0: solar constant value as given in the paper
  // total pressure 1.013 bar held constant
  // published in the paper
  // BC: present-day continents and rotation rate
  // double-checked: 17.9.2013
  plmk, 20000.*1.e-6*1.013, 1093.6/1361., marker=1, msize=.4, color="blue";
  
  // Charnay et al. (2013), no methane, modern cloud droplet size:
  // S0 = 1366 W/m2; solar constant values as given in the paper
  // mean surface pressure 1 bar, partial pressures as reported
  // in the paper
  // double-checked: 17.9.2013
  // 3.8 Ga:
  plmk, 0.01, 1025.1/1361., marker=2, msize=.4, color="blue";
  // 3.0 Ga:
  plmk, 0.01, 1081.9/1361., marker=2, msize=.4, color="blue";
  // 2.5 Ga:
  plmk, 0.01, 1120.8/1361., marker=2, msize=.4, color="blue";
  
  // Le Hir et al. (2013), modern cloud droplet size, 1.7e-6 CH4:
  // BC: realistic topography
  // S0 = ?;  solar constant values as given in the paper
  // double-checked: 17.9.2013
  plmk, 0.0252, 1053./1361., marker=3, msize=.4, color="blue";

      
  logxy, 0, 1;
  limits, xl, xr, 1.5e-4, 2.;
  xytitles, "Solar luminosity relative to today", 
    "CO_2_ partial pressure  (bar)",
    [-0.02,0.01];
  topxtitle, "Time before present (Gyr)", offset=0.04;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  plegend, [4], ["Kienert et al. (2012)"], msize=.6, origin=[.1,.175],
    color="blue";
  plegend, [2,3], ["Charnay et al. (2013)","Le Hir et al. (2014)"], msize=.4, origin=[.40,.175], color="blue";
  plegend, [1,5], ["Wolf & Toon (2013)","Kunze et al. (2014)"], msize=.4, origin=[.7,.175], color="blue";
    
  pdf, "Plots/archean_co2_3d_synthesis_moritz";
  eps, "Plots/archean_co2_3d_synthesis_moritz";
  png, "Plots/archean_co2_3d_synthesis_moritz", dpi=300;
  
}





func plot_archean_nh3( void )
{
  t0 = 273.15;

  // define the plot limits on the x-axis (important for labels on top
  // of the plot!):
  xl = 0.714286;
  xr = 0.958333;

  window, style="notsoflat.gs";
  fma;

  // read Sagan & Mullen (1972) data:
  local t1, s1, t2, s2;
  read_columns, "Data/sagan_mullen_1972_nh3_e09.dat", 1,t1, 2,s1;
  read_columns, "Data/sagan_mullen_1972_co2h2o_e09.dat", 1,t2, 2,s2;
  t1*=-1.;
  t2*=-1.;

  f1 = fitpoly( 3, t1, s1 );
  f2 = fitpoly( 5, t2, s2 );

  plg, t0+[-1.9,-1.9], [5,0], width=2, type="dash";

  grow, t1, [0];
  plg, poly2( t1, f1 ), t1, width=3, color="red";
  plg, poly2( t2, f2 ), t2, width=3, color="blue";

  plt, "Normal freezing point of seawater", 4.4, 275, height=12, tosys=1;
  plt, "NH_3_ / CH_4_ / H_2_O / CO_2_ / H_2_S Greenhouse", 4.2, 360,
    height=14, tosys=1, color="red";
  plt, "CO_2_ / H_2_O Greenhouse", 2, 290, height=14, tosys=1, color="blue";

  xytitles, "Time before present  (Gyr)", "Surface temperature  (K)", 
    [-0.01,0.015];
  limits, 4.6, 0, 250, 410;

  // mark important ages on top of the plot:
  ages = [4.6,3.8,2.5,0.5];
  pldj, ages, array( 402, 4 ), ages, array( 410, 4 );

  plg, [402,402], [4.6,0];

  plt, "Hadean", 4.2, 406, tosys=1, height=12, justify="CH";
  plt, "Archean", 3.15, 406, tosys=1, height=12, justify="CH";
  plt, "Proterozoic", 1.5, 406, tosys=1, height=12, justify="CH";
  plt, "Phanero.", 0.25, 406, tosys=1, height=12, justify="CH";

  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;
  
  // hardcopy:
  eps, "Plots/archean_nh3";
  pdf, "Plots/archean_nh3";

}


func plot_archean_ch4( void )
{

  //  window, style="onepanel.gs";
  window, style="twopanelsh.gs";
  fma;

  // read data for CH4 greenhouse
  local t, ch4, co2;
  read_columns, "Data/haqq-misra_2008_ch4.dat", 1,t, 2,ch4, 3,co2;

  plsys, 1;
  // plot allowed range:
  plfp, .6, [-1.52,-2.86,-1.82], [-1.52,-1.52,-1.82], 3, cmin=0., cmax=1.;
  palette, array(0,255), span(1,255,255), array(0,255);

  // plot haze limit:
  plg, [-3.5,-1.52], [-3.5,-1.52], width=3, color="blue";
  plt, "Haze", -2.7, -2.0, height=14, tosys=1, color="blue";
  xx = span( -3.15, -1.55, 17 );
  pldj, xx, xx, xx-0.1, xx+0.1, color="blue";

  // plot geochemistry limit:
  plg, [-1.52,-5.5], [-1.52,-1.52], width=3, color="red";
  xx = array( -1.52, 17 );
  yy = span( -4.65, -1.55, 17 );
  pldj, xx, yy, xx+0.1, yy-0.1, color="red";
  plt, "Paleosol", -1.125, -2.7, height=14, tosys=1, justify="CH", color="red";
  plt, "limit", -1.125, -2.9, height=14, tosys=1, justify="CH", color="red";

  w = where( t==273 & ch4>0. );
  plg, log10(ch4(w)), log10(co2(w)), type="dash", width=3;
  w = where( t==288 & ch4>0. );
  plg, log10(ch4(w)), log10(co2(w)), width=3;
  plt, "T = 288 K", -2.1, -2.8, height=12, tosys=1, justify="CH";
  plt, "(1D Model)", -2.1, -3.0, height=12, tosys=1, justify="CH";
  plt, "T = 273 K", -2.8, -4.2, height=12, tosys=1, justify="CH";
  plt, "(1D Model)", -2.8, -4.4, height=12, tosys=1, justify="CH";

  // plot function given in Kiehl & Dickinson (1987):
  yy = span( 1, 5, 100 );
  fs = 0.2;
  xx = 7.952 - sqrt(5.647 + 130.42*fs + 0.957*yy + 0.806*yy^2 - 0.0916*yy^3);
  plg, -yy, -xx,  width=3, color=array(150,3);

  // plot erroneous results in Pavlov et al. (2000):
  read_columns, "Data/pavlov_2000_ch4.dat", 2,ch4, 3,co2;
  w = where( ch4>0. );
  plg, log10(ch4(w)), log10(co2(w)), width=3, type="dot";
  
  plt, "(a)", -3.1, -1.6, height=18, tosys=1;
  limits, -3.25, -0.75, -4.75, -1.25;
  xytitles, "", "Log_10_ p CH_4_  (bar)",
    [-0.00,0.01];
  
  // read data for hazy CH4-C2H6 greenhouse
  read_columns, "Data/haqq-misra_2008_ch4_c2h6_haze.dat", 1,t, 2,ch4, 3,co2;


  plsys, 2;

  // plot haze limit:
  plg, [-3.5,-1.52], [-3.5,-1.52], width=3, color="blue";
  plt, "Haze", -2.7, -2.0, height=14, tosys=1, color="blue";
  xx = span( -3.15, -1.55, 17 );
  pldj, xx, xx, xx-0.1, xx+0.1, color="blue";

  // plot geochemistry limit:
  plg, [-1.52,-5.5], [-1.52,-1.52], width=3, color="red";
  xx = array( -1.52, 17 );
  yy = span( -4.65, -1.55, 17 );
  pldj, xx, yy, xx+0.1, yy-0.1, color="red";
  plt, "Paleosol", -1.125, -2.7, height=14, tosys=1, justify="CH", color="red";
  plt, "limit", -1.125, -2.9, height=14, tosys=1, justify="CH", color="red";

  w = where( t==273 & ch4>0. );
  plg, log10(ch4(w)), log10(co2(w)), type="dash", width=3;
  w = where( t==288 & ch4>0. );
  plg, log10(ch4(w)), log10(co2(w)), width=3;
  plt, "T = 288 K", -1.1, -4.2, height=12, tosys=1, justify="CH";
  plt, "(1D Model)", -1.1, -4.4, height=12, tosys=1, justify="CH";
  plt, "T = 273 K", -2.7, -4.2, height=12, tosys=1, justify="CH";
  plt, "(1D Model)", -2.7, -4.4, height=12, tosys=1, justify="CH";

  plt, "(b)", -3.1, -1.6, height=18, tosys=1;
  limits, -3.25, -0.75, -4.75, -1.25;
  rightytitle, "Log_10_ p CH_4_  (bar)";

  plsys, 3;
  xytitles, "Log_10_ p CO_2_  (bar)", "", [-0.005,0.01];
  
  // hardcopy:
  eps, "Plots/archean_ch4";
  pdf, "Plots/archean_ch4";

}


func plot_ch4_history( void )
{
  window, style="notsoflat.gs";
  fma;

  // mark important ages on top of the plot:
  ages = [3.8,2.5,0.5];
  pldj, ages, array( -.775, 3 ), ages, array( -.5, 3 );
  plg, [-.775,-.775], [4.6,-0.2];
  plt, "Hadean",      4.4,   -0.7, tosys=1, height=12;
  plt, "Archean",     3.4,   -0.7, tosys=1, height=12;
  plt, "Proterozoic", 1.8,   -0.7, tosys=1, height=12;
  plt, "Phanerozoic",    0.485, -0.7, tosys=1, height=12;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  // Phanerozoic CH4 concentration from Beerling et al. (2009):
  local t, c;
  read_columns, "Data/beerling_2009.dat", 1,t, 2,c;
  // unit conversions:
  t /= 1000.;
  c *= 1.e-9;
  c += 1.e-12;
  plg, log10(c), t;

  // present-day CH4 concentration:
  plmk, log10(1.8e-6), 0, marker=4, msize=.55, color="red";
  // pre-industrial CH4 concentration:
  plmk, log10(0.715e-6), 0, marker=4, msize=.5, width=2, color="red";

  // abiogenic CH4 flux today scaled to concentration before GOE:
  // potentially larger abiogenic flux due to faster plate tectonics:
  ccc = char([139,69,19]);
  plfp, [ccc], log10([7.e-6,1.e-6,1.e-6]), [3.8,3.8,2.35], [3];
  palette, "earth.gp";

  // Archean biogenic CH4 flux corresponding to 100-1000ppmv:
  yl = 1.e-4;
  yh = 1.e-3;
  ccc = char([0,255,0]);
  nnn = array( 1, 4 );
  
  plfp, [ccc], log10([yh,yl,yl,yh]), [3.55,3.55,2.35,2.35], [4];
  plfp, [ccc], log10([yh,yl,yl,yh]), [3.775,3.775,3.725,3.725], [4];
  plfp, [ccc], log10([yh,yl,yl,yh]), [3.7,3.7,3.65,3.65], [4];
  plfp, [ccc], log10([yh,yl,yl,yh]), [3.625,3.625,3.575,3.575], [4];

  // LHB:
  ccc = char([175,175,175]);
  plfp, [ccc], [-1.5,-6.5,-6.5,-1.5], [4,4,3.8,3.8], [4];
  plt, "Late Heavy Bombardment", 3.85, -1.25, color="black", height=12,
    justify="CH", tosys=1;
  plmk, log10(7.e-6), 3.8, marker=4, msize=.55;


  // mark Great Oxidation Event
  plg, [-1.5,-6.5], [2.35,2.35], width=3, color="blue";
  plt, "Great Oxidation Event", 2.35, -1.25, color="blue", height=12,
    justify="CH", tosys=1;
  plg, [-1.5,-6.5], [.7,.7], width=3, color="blue";
  plt, "Second Rise of Oxygen", .7, -1.25, color="blue", height=12,
    justify="CH", tosys=1;

  // sketch CH4 history:
  plg, [-4.75,-4.75,-3.5,-3.5,-5,-5,-5.5,-5.5,-6.], [4,3.8,3.5,2.4,2.3,0.75,0.65,0.2,0.], width=10, type="dash";

  // Goldblatt et al. (2006):
  plmk, log10(1.e-4), 2.4, marker=4, msize=.55, color="magenta";
  plmk, log10(2.e-5), 2.3, marker=4, msize=.55, color="magenta";

  limits, 4.6, -0.2, -6.5, -0.5;
  xytitles, "Time before present  (Gyr)", 
    "Log_10_ p CH_4_  (bar)", 
    [-0.00,0.015];

  // hardcopy
  eps, "Plots/ch4_history";
  pdf, "Plots/ch4_history";
  
}



func plot_temp_history( void )
{
  t0 = 273.15;

  window, style="notsoflat.gs";
  fma;

  // present-day SST range:
  shade_area, 4.6, -0.2, 271.15, 303.15;
  palette, "gray.gp";
  plt, "Present-day ocean temperature range", 2.05, 286.15,
    height=12, color=[50,50,50], tosys=1;

  // freezing and boiling point:
  plg, t0+[-1.9,-1.9], [4.6,-0.2], width=3, type="dash";
  // plg, t0+[100.56,100.56], [4.6,-0.2], width=3, type="dash";
  //  plt, "Normal boiling point of seawater", 4.4, 376, height=12, tosys=1;
  plt, "Normal freezing point of seawater", 4.4, 265, height=12, tosys=1;

  // upper limit gypsum:
  plg, t0+[58.,58.], [3.5,-0.2], width=3, color="cyan";
  plt, "Gypsum", .8, 335, color="cyan", height=12, tosys=1;

  // upper limit life (Walker, 1982):
  read_columns, "Data/walker_1982_life.dat", 1,a, 2,t;
  t += t0;
  plg, t, a, width=3, color="green";
  plt, "Life", .65, 317, color="green", height=12, tosys=1;

  // Knauth & Epstein (1976):
  plmk, t0+[52.,70.], [1.3,3.0], marker=4, msize=.5, color="blue";
  plg, t0+[42,62], [1.3,1.3], width=3, color="blue";
  plg, t0+[60,80], [3.0,3.0], width=3, color="blue";
  plt, "Knauth & Epstein (1976)", 2.8, 335, color="blue", height=12, tosys=1;

  // Knauth & Lowe (2003):
  plmk, t0+70, 3.3, marker=4, msize=.5, color=[125,125,255];
  plg, t0+[55,85], [3.3,3.3], width=3, color=[125,125,255];
  plt, "Knauth & Lowe (2003)", 4.55, 350, color=[125,125,255],
    height=12, tosys=1;

  // Hren et al. (2009):
  plmk, t0+40, 3.42, marker=4, msize=.5, color="red";
  plg, t0+[30,40], [3.42,3.42], width=3, color="red";
  plg, t0+[29,35], [3.42,3.38], width=3, color="red";
  plg, t0+[29,35], [3.42,3.46], width=3, color="red";
  plt, "Hren et al. (2009)", 4.47, 312, color="red", height=12, tosys=1;

  // Blake et al. (2010):
  plmk, t0+30.5, 3.35, marker=4, msize=.5, color="magenta";
  plg, t0+[26,35], [3.35,3.35], width=3, color="magenta";
  plt, "Blake et al. (2010)", 3.2, 305, color="magenta",
    height=12, tosys=1;

  // mark important ages on top of the plot:
  ages = [3.8,2.5,0.5];
  pldj, ages, array( 402, 3 ), ages, array( 410, 3 );
  plg, [402.,402.], [4.6,-0.2];
  plt, "Hadean",      4.4,   404, tosys=1, height=12;
  plt, "Archean",     3.4,   404, tosys=1, height=12;
  plt, "Proterozoic", 1.8,   404, tosys=1, height=12;
  plt, "Phanerozoic",    0.485, 404, tosys=1, height=12;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  //  plegend, [4,4,4,4], ["Knauth & Epstein (1976)","Knauth & Lowe (2003)",
  //                       "Hren et al. (2009)","Blake et al. (2010)"],
  //    marker=4, msize=.5, color=[[150,150,255],"blue","red","magenta"];

  limits, 4.6, -0.2, 250, 409;
  xytitles, "Time before present  (Gyr)", 
    "Temperature  (K)", [-0.01,0.015];

  // hardcopy
  eps, "Plots/temp_history";
  pdf, "Plots/temp_history";
  
}



func plot_solar_lum( color= )
{

  t = span( 0., 4.6, 1000 );
  l = gough_age_to_L( t );

  window, style="notsoflat.gs";
  fma;
  if( is_void(color) )
    plg, l, t, width=3, type="dash";
  else
    plg, l, t, width=3, color="blue";

  read_columns, "Data/bahcall_2001_ssm.dat", 1,tt, 2,ll;
  xx = span( 4.57, 0., 100 );
  lx = interp( ll, 4.57-tt, xx );
  yy = spline( ll(1:4), 4.57-tt(1:4), xx(1:4) );
  lx(1:4) = yy;
  if( is_void(color) )
    plg, lx, xx, width=3;
  else
    plg, lx, xx, width=3, color="red";

  // radiative forcing at beginning and end of archean:
  w1 = where(abs(xx-3.8)<0.02);
  (1.-lx(w1))*(1.-0.3)/4.*1360.8;
  w2 = where(abs(xx-2.5)<0.02);
  (1.-lx(w2))*(1.-0.3)/4.*1360.8;

  limits, 4.6, 0, 0.66, 1.04;
  if( is_void(color) )
    xytitles, "Time before present  (Gyr)", "Solar luminosity relative to today", [-0.01,0.015];
  else
    xytitles, "Time before present  (Ga)", "Solar luminosity relative to today", [-0.01,0.015];


  // mark important ages on top of the plot:
  if( !is_void(color) ){
    s = array( 0, [2,1,1] );
    pli, bytscl( s, cmin=0, cmax=1), 3.8, 1.01, 2.5, 1.04;

    // create a special colour palette for this plot (light blue as
    // lowest value, light cyan as highest value, dark green in between)
    // - from the CCN plot in neop.i:
    r = [150]; grow, r, span(50, 255, 238); grow, r, [150];
    g = [150]; grow, g, span(75, 255, 238); grow, g, [255];
    b = [255]; grow, b, span(0, 255, 238); grow, b, [255];
    palette, r,g,b;
  }

  ages = [3.8,2.5,0.542];
  pldj, ages, array( 1.04, 3 ), ages, array( 1.01, 3 );

  plg, [1.01,1.01], [4.6,0.];

  plt, "Hadean",      4.200, 1.025, tosys=1, height=12, justify="CH";
  plt, "Archean",     3.150, 1.025, tosys=1, height=12, justify="CH", font="helveticaB";
  plt, "Proterozoic", 1.521, 1.025, tosys=1, height=12, justify="CH";
  plt, "Phanero-", 0.271, 1.0325, tosys=1, height=12, justify="CH";
  plt, "zoic", 0.271, 1.0175, tosys=1, height=12, justify="CH";


  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  if( is_void(color) )
    plegend, ["solid","dash"], ["Bahcall et al. (2001)", "Gough (1981)"],
      width=3, length=0.049, height=14, origin=[0.08,0.9];
  else
    plegend, ["solid","solid"], ["Bahcall et al. (2001)", "Gough (1981)"],
      color=["red","blue"], width=3, length=0.049, height=14, origin=[0.08,0.9];

  if( is_void( color ) )
    filename = "Plots/sollum";
  else
    filename = "Plots/sollum_color";
  pdf, filename;
  eps, filename;
  png, filename, dpi=300;
  
}


func plot_temp_solar_lum( void )
{

  t = span( 0., 4.6, 1000 );
  l = gough_age_to_L( t );

  window, style="notsoflat_twoaxis.gs";
  fma;

  plsys, 1;
  shade_area, 4.6, 0., 235, 273.15;
  palette, "gray.gp";
  read_columns, "Data/kasting_1989.dat", 1,tt, 2,sat;
  f = fitpoly( 2, tt, sat );
  ttt = span( 4.6, 0., 100 );
  plg, poly2( ttt, f ), ttt, width=3, color="blue";
  limits, 4.6, 0, 235, 305;

  plsys, 2;
  plg, l, t, width=3, color="red";
  rightytitle, "Solar luminosity relative to today", offset=.06;

  limits, 4.6, 0, 0.675, 1.025;
  xytitles, "Time before present  (Gyr)", "Earth surface temperature  (K)", [-0.0,0.015];


  // mark important ages on top of the plot:
  ages = [3.8,2.5,0.5];
  pldj, ages, array( 1.025, 3 ), ages, array( 1.005, 3 );

  plg, [1.005,1.005], [4.6,0.];

  plt, "Hadean",      4.4,   1.012, tosys=1, height=12;
  plt, "Archean",     3.4,   1.012, tosys=1, height=12;
  plt, "Proterozoic", 1.8,   1.012, tosys=1, height=12;
  plt, "Phanero.",    0.485, 1.012, tosys=1, height=12;

  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;

  plegend, ["solid","solid"], ["Surface temperature", "Solar luminosity"],
    color=["blue","red"], width=3, length=0.049, height=14, origin=[0.08,0.9];

  pdf, "Plots/temp_sollum";
  eps, "Plots/temp_sollum";
  png, "Plots/temp_sollum", dpi=300;
  
}


func plot_iceline( void )
{
  // initialise display:
  window, style="onepanel_majorticks.gs";
  fma;



  // today:
  plg, [0,90], [1,1], width=2;
  plmk, 65, 1, marker=4, msize=.7;
  plt, "Today", 0.97, 65, tosys=1, height=14, justify="RH";
  plt, "Glacial branch", 0.7, 47.5, tosys=1, height=14;

  // other branches:
  xx  = span(pi,2*pi,100);

  zz4 = span(26,75,100);
  yy4 = cos(xx)/2.*(1.07-0.89)+0.98;
  plg, zz4, yy4, width=6, color=[125,125,125];

  zz5 = span(26,0,100);
  yy5 = cos(xx)/2*.35+1.065;
  plg, zz5, yy5, width=6, type="dash", color=[125,125,125];

  zz6 = span(90,75,100);
  yy6 = cos(xx)/100.+1.06; 
  plg, zz6, yy6, width=6, type="dash", color=[125,125,125];

  zz1 = span(30,66,100);
  yy1 = cos(xx)/20.+0.95;
  plg, zz1, yy1, width=6;
  zz2 = span(90,66,100);
  yy2 = cos(xx)/100.+0.99; 
  plg, zz2, yy2, width=6, type="dash";
  zz3 = span(30,0,100);
  yy3 = cos(xx)/2*.35+1.075;
  plg, zz3, yy3, width=6, type="dash";
  plt, "70% meridional", 1.225, 70, height=14, tosys=1, color=[125,125,125],
    justify="CH";
  plt, "heat transport", 1.225, 64, height=14, tosys=1, color=[125,125,125], 
    justify="CH";

  // waterworld:
  plg, [90,90], [0.98,1.4], width=6;
  plt, "Ice-free branch", 1.075, 92.5, tosys=1, height=14;

  // snowball Earth:
  plg, [0,0], [0.6,1.25], width=6;
  plt, "Ice-covered branch", 0.775, -6, tosys=1, height=14;

  // changes in heat transport:
  plg, [63,55.], [1,1], width=5, color="blue";
  plg, [58,55.], [0.99,1], width=5, color="blue";
  plg, [58,55.], [1.01,1], width=5, color="blue";

  plg, [30,30], [0.9,0.885], width=5, color="red";
  plg, [30,31.5], [0.885,0.90], width=5, color="red";
  plg, [30,28.5], [0.885,0.90], width=5, color="red";


  // diagram legends and limits:
  plegend, ["solid","dash"], ["stable","unstable"], 
    width=6, length=0.055, origin=[0.07,0.95];
  xytitles, "Solar luminosity relative to today", "Latitude of ice line  (deg)",
    [0.,0.01];
  limits, 0.6, 1.4, -10, 100;
  gridxy, base60=3;

  // hardcopy:
  eps, "Plots/iceline";
  pdf, "Plots/iceline";

}


func plot_crustal_growth( void )
{
  window, style="notsoflat.gs";
  fma;

  // mark important ages on top of the plot:
  ages = [3.8,2.5,0.5];
  pldj, ages, array( 1.05, 3 ), ages, array( 1.0, 3 );
  plg, [1.,1.], [4.6,0.];
  plt, "Hadean",      4.4,   1.015, tosys=1, height=12;
  plt, "Archean",     3.4,   1.015, tosys=1, height=12;
  plt, "Proterozoic", 1.8,   1.015, tosys=1, height=12;
  plt, "Phanero.",    0.485, 1.015, tosys=1, height=12;
  // switch off ticks on top of the plot:
  gridxy, 0x621, 0;


  //  tt = span( 4.6, 0., 45 );
  //  local t, v;
  //  read_columns, "Data/Crustal_Growth/hurley_rand_1969.dat", 1,t, 2,v;
  //  plg, spline(v,t,tt), tt, width=3, color="black";
  //
  //  read_columns, "Data/Crustal_Growth/fyfe_1978.dat", 1,t, 2,v;
  //  plg, spline(v,t,tt), tt, width=3, color="blue";
  //
  //  read_columns, "Data/Crustal_Growth/armstrong_1981.dat", 1,t, 2,v;
  //  plg, spline(v,t,tt), tt, width=3, color="green";
  //
  //  read_columns, "Data/Crustal_Growth/reymer_schubert_1984.dat", 1,t, 2,v;
  //  plg, spline(v,t,tt), tt, width=3, color="red";
  //
  //  read_columns, "Data/Crustal_Growth/taylor_mclennan_1985.dat", 1,t, 2,v;
  //  plg, spline(v,t,tt), tt, width=3, color="magenta";
  //
  //  read_columns, "Data/Crustal_Growth/campbell_2003.dat", 1,t, 2,v;
  //  plg, spline(v,t,tt), tt, width=3, color=[255,140,0];

  read_columns, "Data/Crustal_Growth/belousova_2010.dat", 1,t, 2,v;
  tt = span( 4.6, 0., 45 );
  plg, interp(v,t,tt), tt, width=3, color="blue";

  tt = span( 4.6, 0., 10000 );
  read_columns, "Data/Crustal_Growth/dhuime_2012.dat", 1,t, 2,v;
  w = where( t>=3. );
  ww = where( tt>=3. );
  f = fitpoly( 3, t(w), v(w) );
  plg, poly2( tt(ww), f ), tt(ww), width=3, color="red";
  w = where( t>=2.2 & t<=3.4 );
  ww = where( tt>=2.6 & tt<=3 );
  f = fitpoly( 5, t(w), v(w) );
  plg, poly2( tt(ww), f )-0.0022, tt(ww), width=3, color="red";
  w = where( t<=2.6 );
  ww = where( tt<=2.6 );
  f = fitpoly( 3, t(w), v(w) );
  plg, poly2( tt(ww), f ), tt(ww), width=3, color="red";

  xytitles, "Time before present  (Gyr)", 
    "Continental volume relative to today", [0.,0.015];
  limits, 4.6, 0, 0., 1.05;

  plegend, ["solid","solid"], ["Belousova et al. (2010)",
                               "Dhuime et al. (2012)"],
    color=["blue","red"], width=3;

  // hardcopy
  eps, "Plots/crust";
  pdf, "Plots/crust";

}



func plot_archean_albedo_3d( void )
{
  // read model albedo data:
  local p, as, ap;
  read_columns, "Albedo/albedo5001.dat", 1,p, 2,as, 3,ap;

  // initialise display:
  window, style="notsoflat.gs";
  fma;

  // plot albedo:
  plg, [0.21,0.21], [0.2,1.1], width=3, color=[0,150,0];
  plmk, as, p, marker=4, msize=.4, color="blue";
  plmk, ap, p, marker=1, msize=.4, color="red";

  // mark present-day albedo:
  plg, [0.3,0.3], [0.261,0.31], width=2, color="red";
  plg, [0.3,0.314], [0.26,0.275], width=2, color="red";
  plg, [0.3,0.286], [0.26,0.275], width=2, color="red";
  plt, "A_P_ (PD)", 0.32, 0.3, height=14, tosys=1, justify="LH",
    color="red";
  plg, [0.12,0.12], [0.261,0.31], width=2, color="blue";
  plg, [0.12,0.134], [0.26,0.275], width=2, color="blue";
  plg, [0.12,0.106], [0.26,0.275], width=2, color="blue";
  plt, "A_S_ (PD)", 0.32, 0.12, height=14, tosys=1, justify="LH",
    color="blue";

  // marke ice-line:
  plg, [0.451,0.55], [0.4,0.4], width=2;
  plg, [0.45,0.48], [0.4,0.39], width=2;
  plg, [0.45,0.48], [0.4,0.41], width=2;
  plt, "34° N/S", 0.4, 0.575, height=14, tosys=1, justify="CH";
  plg, [0.376,0.475], [0.6,0.6], width=2;
  plg, [0.375,0.405], [0.6,0.59], width=2;
  plg, [0.375,0.405], [0.6,0.61], width=2;
  plt, "54° N/S", 0.6, 0.5, height=14, tosys=1, justify="CH";

  // limits, legends etc.:
  limits, 0.25, 1.05, 0, 0.9;
  xytitles, "CO_2_ partial pressure  (bar)",
    "Global annual mean albedo", [0.,0.01];
  plegend, [4,1], ["surface albedo (A_S_)","planetary albedo (A_P_)"],
    color=["blue","red"], msize=.4, origin=[0.6,0.95], height=14;
  pldj, [0.7,1.,1.,0.7], [0.85,0.85,0.715,0.715],
    [1.,1.,0.7,0.7], [0.85,0.715,0.715,0.85], width=2;

  // hardcopy:
  eps, "Plots/archean_albedo_3d";
  pdf, "Plots/archean_albedo_3d";
  png, "Plots/archean_albedo_3d", dpi=600;

}


// computes energy deposited by impacts from space in today's climate:
func impact_energy( void )
{
  local e, p;
  read_columns, "Impact_Energy/impact_energy.dat", 1,e, 2,p;
  // units of e: J
  // units of p: 1/yr

  fma;
  plg, log10(p), log10(e);

  ee = span( min(e), max(e), 10000000 );
  pp = interp( p, e, ee );
  de = ee(2)-ee(1);

  plg, log10(pp), log10(ee), color="red";

  // the raw integrals are in units of J/yr, we would like to have W, however,
  // so we have to divide by a factor f of
  f = 365.*24.*3600;
  integ( p, e, max(e) )/f;
  integ( pp, ee, max(e) )/f;
  sum( pp(where(ee<=max(e)))*de )/f;
}


func conc_to_partial ( c_trace, m_trace, p_i_air, m_air )
/* DOCUMENT:

   p_trace = conc_to_partial( c_trace, m_trace, , p_i_air, m_air )

   Converts the concentration of any trace gas c_trace (e.g. CO2) with
   molecular weight m_trace to the partial pressure (in bar if the
   surface pressure p_i_air that all the other gases (with molecular
   weight m_air) in the air would exert if it were unmixed with any
   other gases is given in bar. See Pierrehumbert et al. (2011,
   Ann. Rev. Earth Planet. Sci., 39, 417; pages 427-428) for a
   detailed discussion.

   Review status: formula checked, output tested against Table 1 in
   Pierrehumbert et al. (2011); 17.9.2013

 */
{
  return p_i_air*c_trace*( 1. + c_trace/(1.-c_trace)*m_trace/m_air );
}


func gough_L_to_age( l_over_l0 )
{
  t0 = 4.57;
  return t0*2.5*( 1./l_over_l0 - 1. );
}

func gough_age_to_L( age )
{
  t0 = 4.57;
  return 1./(1. + 0.4*(1.-(t0-age)/t0) );
}


func plot_archean_topog( file= )
{
  if( is_void(file) )
    file = "topog.dta.nc";

  cmin=-4000.;
  cmax=1.;
  
  f = nc_open( file );
  
  z = f.ht;
  w = where( z<-1.e33 );
  z(w) = -100.;
  z *= -1.;
  z /= 100.; // convert to m

  window, style="worldmap.gs";
  fma;

  colorbar_, cmin, 0, viewport=[0.20,0.60,0.42,0.43], 
    nminor=10, tlabel_b=1, horizontal=1,
    tlabel_height=12;
  plt, "Depth (m)", 0.62, 0.3995, tosys=0, height=12;

  pli, z, -180, -90, 180, 90, cmin=cmin, cmax=cmax;
  palette, "bluebrown.gp";
  gridxy, base60=3;
  xytitles, "Longitude", "Latitude", [0.01,0.02];


  eps, "archean_topog";
  pdf, "archean_topog";

}


func test_rad_trans( void )
{
  m = span( 0.3, 400., 100 );

  window, style="notsoflat.gs";
  fma;

  // ITF following Petoukhov (1991):
  a0 = 0.907;
  a1 = 0.047;
  plg, a0 - a1*log10(m), m, width=3, color="red";

  // ITF approximation implemented in POTSDAM2:
  a  = 0.247;
  ap = 0.755;
  b  = 0.509;
  b0 = 1.66;
  plg, ( 1. + a*ap*(b0*m)^b )/( 1. + a*(b0*m)^b ), m, width=3, color="blue";

  limits, 0, 400, 0.75, 1.;
  xytitles, "CO_2_ effective absorber mass  (cm)", "CO_2_ integrated transfer function";
  plegend, ["solid","solid","solid"], ["Petoukhov (1991)","CLIMBER original","CLIMBER improved"], color=["red","blue","green"], width=3, origin=[0.6,0.9];

}



func bluebrown_color_palette( void )
{
  rise = bytscl( indgen(100), top=200 )+50;
  high = array( 255, 100 );
  zero = array( 0, 100 );

  rgb_r = rgb_g = rgb_b = [];
  grow, rgb_r, zero, rise, [136];
  grow, rgb_g, zero, rise, [69];
  grow, rgb_b, rise, high, [19];

  palette, rgb_r, rgb_g, rgb_b;
  dump_palette, "bluebrown.gp";
}


func shade_area( xlow, xhigh, ylow, yhigh, level= )
{
  if( is_void(level) )
    level = 0.8;
  s = array( level, [2,1,1] );
  pli, bytscl( s, cmin=0, cmax=1), xlow, ylow, xhigh, yhigh;
}



func average_iceboundaries( l1, l2 )
{
  lat = span( -90., 90.,1440 );
  w    = cos(lat/180.*pi);
  w1   = ( lat>=l1 );
  w2   = ( lat>=l2 );
 
  a1 = sum(w*w1)/sum(w);
  a2 = sum(w*w2)/sum(w);

  a = (a1+a2)/2.;

  for( n=1; n<=numberof(lat); n++ ){
    if( lat(n)<l1 | lat(n)>l2 )
      continue;
    wl = ( lat>=lat(n) );
    al = sum(w*wl)/sum(w);
    da = al-a;
    if( abs(da)<.0001 )
      write, lat(n), da/lat(n);
  }

}


func plot_albedo( void )
{
  local t, ap, as, ib;
  read_columns, "Albedo/albedo_data.dat", 1,t, 2,ap, 3,as, 4,ib;

  // compute snowball and ice-free albedos:
  ap_c = avg(ap(where(t<265.)));
  ap_w = avg(ap(where(t>300.)));
  as_c = avg(as(where(t<265.)));
  as_w = avg(as(where(t>300.)));

  // compute slopes:
  w = where( t>265. & t<300. );
  fp = fitline( t(w), ap(w) );
  fs = fitline( t(w), as(w) );

  fp(2); fs(2);

  // initialise display:
  window, style="notsoflat.gs";
  fma;

  // plot the parameterisation:
  plg, ap_c*[1,1], [255,268], width=2, color="red";
  plg, as_c*[1,1], [255,268], width=2, color="blue";
  plg, ap_w*[1,1], [300,305], width=2, color="red";
  plg, as_w*[1,1], [300,305], width=2, color="blue";
  tt = span( 268., 300., 10 );
  plg, fp(1)+fp(2)*tt, tt, width=2, color="red";
  plg, fs(1)+fs(2)*tt, tt, width=2, color="blue";

  // plot simulation results:
  plmk, ap, t, marker=4, msize=.5, color="red";
  plmk, as, t, marker=4, msize=.5, color="blue";
  
  limits, 255, 305, 0, 1;
  
}


func plot_solar_analogs( void )
{
  // read data from Table 3 in Güdel (2007), Living Reviews in Solar
  // Physics, 4, 3
  local Teff, Mass, Radius, Lbol, Age, Flag;
  read_columns_mixed, "Data/sun_in_time.dat", 6,Teff, 7,Mass, 8,Radius, 10,Lbol, 
    12,Age, 13,Flag;

  // correct bolometric luminosity using mass-luminosity relation:
  Lbol /= Mass^4;

  // make the plot:
  window, style="notsoflat.gs";
  fma;
  // plot Bahcall (2001) standard solar model:
  read_columns, "Data/bahcall_2001_ssm.dat", 1,tt, 2,ll;
  plg, ll, tt, width=3, color="blue";
  // mark unresolved binaries:
  bin = where( Flag=="binary" );
  plmk, Lbol(bin), Age(bin), marker=4, msize=.8, width=2;
  plmk, 1, 4.6, marker=4, msize=1., width=3, color="red";
  plmk, Lbol, Age, marker=4, msize=.5, color="red";
  xytitles, "Age  (Gyr)", "Luminosity relative to solar luminosity", [0.,0.01];
  limits, 0, 10, 0.25, 1.75;
  plegend, ["solid"], ["Standard solar model (Bahcall et al. 2001)"], color="blue", width=3,
    origin=[0.4,0.3];
  plegend, [4,4,4], ["Solar analogs (Guedel 2007)","Sun","Binary"], color=["red","red","black"], 
    msize=[.5,1.,0.8], width=[100,3,2], origin=[0.458,0.26];

  outfile="Plots/solar_analogs";
  pdf, outfile;
  eps, outfile;
  png, outfile, dpi=600;
    

}


func plot_for_sfb( external= )
{
  // check whether cluster file system is mounted:
  ld = lsdir( "/Volumes/HLRS2015" );
  if( ld==0 ){
    system, "mkdir /Volumes/HLRS2015";
    if( is_void( external ) )
      system, "sshfs feulner@hlrs2015:/ /Volumes/HLRS2015/";
    else
      system, "sshfs feulner@cluster.pik-potsdam.de:/ /Volumes/HLRS2015/";
  }
  path="/Volumes/HLRS2015/p/projects/ace/kienert/archean/final2_part1/critical_co2/c3beta_archean_final2_1p-ran-C_0p7525_0p40bar/";

  // read data:
  infile = path+"snapshots.005901.01.01.dta.nc";
  d = nc_openf( infile, data, meta );
  m = meta.numrecs;
  sst = data.temp(,,1)*0.;
  for( n=1; n<=m; n++ ){
    jr, data, n;
    sst += data.temp(,,1);
  }
  sst /= 12.;

  
  // init display:
  window, style="worldmap.gs";
  fma;


  
}
