/*
   GRAPHLIB.I
   Miscellaneous graphics and plotting routines

   $Id: graphlib.i,v 1.22 2004/11/05 21:38:49 drory Exp $
*/

require, "style.i"



  func colorbar_( cmin, cmax, sys=, viewport=, tlabel_l=, tlabel_r=, tlabel_b=, tlabel_u=, 
                  tlabel_height=, nminor=, nmajor=, horizontal=, ftype= )
/* DOCUMENT
   colorbar_, cmin, cmax, sys=, viewport=

   Draw a color bar into a new coordinate system sys at the
   NDC coordinates viewport=[x1,x2,y1,y2].
   The color range is goes from cmin to cmax and is labeled left or right
   according to label_l=, label_r=, tlabel_height= (see place_plsys)
*/
{
   p = plsys();

   if( is_void(sys) )
      sys = 2;
   if( is_void(viewport) )
      viewport = [.625, .65, .46, .84];

   if( is_void(cmin) )
      cmin=0;
   if( is_void(cmax) )
      cmax=1;

   if( is_void(horizontal) )
     if( is_void(tlabel_r) & is_void(tlabel_l) ){
       tlabel_r = 1;
       tlabel_l = 0;
     }
   if( !is_void(horizontal) )
     if( is_void(tlabel_b) & is_void(tlabel_u) ){
       tlabel_b = 1;
       tlabel_u = 0;
     }


   if( is_void(horizontal) )
     place_plsys, sys, viewport(1), viewport(2), viewport(3), viewport(4),
       tmark_b=0, tmark_u=0, tlabel_l=tlabel_l, tlabel_r=tlabel_r,
       tlabel_b=tlabel_b, tlabel_u=tlabel_u, tlabel_height=tlabel_height, 
       nminor=nminor, nmajor=nmajor, ftype=ftype;
   else
     place_plsys, sys, viewport(1), viewport(2), viewport(3), viewport(4),
       tmark_l=0, tmark_r=0, tlabel_l=tlabel_l, tlabel_r=tlabel_r,
       tlabel_b=tlabel_b, tlabel_u=tlabel_u, tlabel_height=tlabel_height, 
       nminor=nminor, nmajor=nmajor, ftype=ftype;
     

   plsys, sys;

   if( is_void(horizontal) ){
     pli, span(cmin,cmax,1000)(-,), 0, cmin, 1, cmax, cmin=cmin, cmax=cmax;
   }
   else{
     pli, span(cmin,cmax,1000)(,-), cmin, 0, cmax, 1, cmin=cmin, cmax=cmax;
     //     plt, "C", viewport(2)+0.03, viewport(3), height=12;
   }
     
   plsys, p;
}



func plarrow( x0, y0, x1, y1, width=, type=, color=, msize=, filled= )
/* DOCUMENT
   plarrow, x0, y0, x1, y1, width=, type=, color=, msize=, filled=;

   Plot disjoint lines with arrows at their ends (x1,y1). 
   width=, type=, and color= influence the lines,
   msize=, and filled=0/1 are for the arrowhead.
   
   The rest is identical to pldj.

   SEE ALSO: pldj, plmk
*/
{
   if( is_void(msize) )
      msize = _plmk_msize;
   if( is_void(filled) )
      filled = 0;
   if( is_void( width ) )
      width = 2;

   fac = 1.0*msize;

   // arrowhead
   xmk = [0.,1.,0.,-1.,0.] * fac;
   ymk = [0.,-1.,4.,-1.,0.] * fac;

   // rotate the arrowhead
   theta = atan(y1-y0, x1-x0);

   for( i=1; i<=numberof(theta); ++i )
   {
      mx =  xmk*cos(theta(i)) + ymk*sin(theta(i));
      my = -xmk*sin(theta(i)) + ymk*cos(theta(i));

      plmk, [y1(i)],[x1(i)], marker=[mx,my], msize=msize,
         color=color, width=(filled==1 ? 10 : width), edges=(filled==1 ? 0 : 1);
   }

   pldj, x0, y0, x1, y1, width=width, type=type, color=color;
}


func plcm( c, y, x, marker=, width=, msize=, edges= )
/* DOCUMENT
   plcm, c,y,x, marker=,width=,color=,msize=,edges=

   Make a scatter plot of the points Y versus X using color C.
   The rest is identical to plmk.
*/
{
   if (is_void(marker))
   {
      marker= (_plmk_count-1)%7 + 1;
      _plmk_count++;
   }
   if (numberof(marker)==1)
   {
      marker= *_plmk_markers(marker);
   } else if (dimsof(marker)(1)!=2 || dimsof(marker)(3)!=2 ||
              dimsof(marker)(2)<=2)
   {
      error, "illegal marker= keyword value";
   }
   xm= marker(,1);
   ym= marker(,2);
   if (is_void(msize)) msize= _plmk_msize;
   if (!is_void(msize))
   {
      xm*= msize;
      ym*= msize;
   }
   if (is_void(color)) color= _plmk_color;
   if (structof(color)==string)
   {
      n= where(color==["bg","fg","black","white",
                       "red","green","blue","cyan","magenta","yellow"]);
      if (numberof(n)!=1) error, "unrecognized color name: "+color;
      color= char(-n(1));
   }
   ecolor= _plmk_color;
   if (is_void(width)) width= _plmk_width;
   if (!is_void(width))
   {
      if (width>=10)
      {
         solid= 1;
         if (is_void(color)) color= ecolor= char(-2);
         width= [];
      }
   }
   n= array(1,1+numberof(y));
   n(1)= numberof(ym);
   if (is_void(x)) x= indgen(numberof(y));
   plfp, grow([0],c),grow(ym,y),grow(xm,x),n,edges=edges,
      ewidth=width,ecolor=ecolor;
}


func plh_old( y, x, marks=, color=, type=, width=, marker=,sep= )
     /* DOCUMENT
	plh, y, x;

	Plot the histogram data computed by hist() in mathlib.i.  y is
	an array containing the frequencies, x is an array containig
	the bins. Thus y(i) is the frequency of values v for which
	x(i) <= v < x(i+1), and numberof(x) = numberof(y)+1.
	KEYWORDS: marks, color, type, width
	SEE ALSO: hist
     */
{
  if( numberof(x) != numberof(y)+1 ) error, "y array must have exactly numberof(x)-1 elements!";
  if( is_void(sep) ) sep=0;
  if( !sep || numberof(y)==1 )
  {
    yy = xx = array(0.0, 2*numberof(x));
    yy(2:-2:2) = yy(3:-1:2) = y;        /* replicate y values */
    xx(1:-1:2)=xx(2:0:2)=x(1:0);        /* replicate x values */
  }
  else
  {
    yy=xx=array(0.0, 3*numberof(x)-2);
    yy(2:-2:3)=yy(3:-1:3)=y;                       /* replicate y values */
    xx(1:-3:3)=xx(2:-2:3)=x(1:-1);                 /* replicate x values */
    xx(3:-4:3)=x(2:-1);                            /* replicate x values */
    xx(-1:0)=x(0);                                 /* replicate x values */
  }
  plg, yy, xx, marks=marks, color=color, type=type, width=width, marker=marker;
}



func pley( ymin, ymax, x, legend=, hide=, type=, width=, color= )
     /* DOCUMENT
	pley, ymin, ymax, x, legend=, hide=, type=, width=, color=;

	Plot y errorbars ranging from ymin to ymax at x.
	Keywords: legend, hide, type, width, color
      */
{
  pldj, x, ymin, x, ymax,
    legend=legend, hide=hide, type=type, width=width, color=color;
}


func plex( xmin, xmax, y, legend=, hide=, type=, width=, color= )
     /* DOCUMENT
	plex, xmin, xmax, y, legend=, hide=, type=, width=, color=;

	Plot x errorbars ranging from xmin to xmax at y.
	Keywords: legend, hide, type, width, color
      */
{
  pldj, xmin, y, xmax, y,
    legend=legend, hide=hide, type=type, width=width, color=color;
}




func plshade(x1, y1, x2, y2, n=, type=, width=, color=)
     /* DOCUMENT
	plshade, x1, y1, x2, y2, n=, type=, width=, color=;

	Shade the region between piecewise linear curves x1, y1 and
	x2, y2. N lines are used for shading.
     */
{
  if( int(limits()(5)) & 128 )
    logx=1;

  if( is_void(n) )
    n=100;

   if( logx )
     xx=spanl(min(x1), max(x1), n);
   else
     xx=span(min(x1), max(x1), n);

  yy1 = interp( y1, x1, xx);
  yy2 = interp( y2, x2, xx);

  pldj, xx, yy1, xx, yy2, type=type, width=width, color=color;
}


func plottitle( title, offset=, font=, height= )
     /* DOCUMENT
	plottitle, title, offset=, font=, height=

	Plot a title centered above the coordinate system for any of the
	standard Gist styles.  You may want to customize this for other
	plot styles. One may directly specify font, font height, and the
	offset from the box as keyword arguments.
	KEYWORDS:
	   offset= offset from viewport in NDC, defaults to 0.02
	   font= font to use
	   height= font height
	SEE ALSO: plt, xytitles, pltitle
     */
{
  extern pltitle_font, pltitle_height;

  if( is_void( offset ) )
    offset=0.02;
  if( is_void( font ) )
    font=pltitle_font;
  if( is_void( height ) )
    height=pltitle_height;

  port= viewport();
  plt, title, port(zcen:1:2)(1), port(4)+offset,
    font=font, justify="CB", height=height;
}



func rightytitle( title, offset= )
     /* DOCUMENT

	rightytitle, title, offset=;
	Plot a title for the right y axis.
	SEE ALSO: xytitles, plt, pltitle
     */
{
  extern pltitle_font, pltitle_height;

  if( is_void( offset ) )
      offset = 0.05;

  port=viewport();

  plt, title, port(2)+offset, port(zcen:3:4)(1),
    font=pltitle_font, height=pltitle_height, justify="CB", orient=3;
}

func topxtitle( title, offset= )
     /* DOCUMENT

	topxtitle, title, offset=;
	Plot a title for the top x axis.
	SEE ALSO: xytitles, plt, pltitle
     */
{
  extern pltitle_font, pltitle_height;

  if( is_void( offset ) )
      offset = 0.05;

  port=viewport();

  plt, title, port(zcen:1:2)(1), port(4)+offset,
    font=pltitle_font, height=pltitle_height, justify="CB", orient=0;
}



func plegend( marker, text, origin=, length=, gap=,
	      width=, color=, msize=, edges=,
	      font=, height=, baselinestretch=,
              coltext=, rgbcolor= )
  /* DOCUMENT
     plegend, marker, text,
	      width=, color=, msize=,
	      font=, height=, baselinestretch=,
	      origin=, length=, gap=;

     Plot a legend into the current coordinate system.

     INPUTS:
       marker      Array with linestyles ["solid", "dash", ...]
                   or marker types [1,4,3,...] to label in top-down order.
       text        Array with labels for markers. Must have same length.

       width=      Width of lines/markers. If this is a scalar, all get
                   the same width. If it is an array, each gets
		   the corresponding width.
       color=      Color of lines/markers. Scalar or array.
       msize=      Sizes of markers. Scalar or array.
       edges=      Edges of markers. Scalar or array.
       font=       Font for labels (scalar only).
       height=     Font height in points (scalar only).
       baselinestretch=
                   Factor for spacing between lines in the legend.

       origin=     Upper left corner of legend relative to the current
                   viewport.
                   The viewport has coordinates ll=[0,0], ur=[1,1]
		   (lower-left, upper-right). Defaults to [0.07, 0.93],
		   so the legend is in the upper-left corner of the plot
		   by default.
       length=     Length of line-style examples in NDC. Defaults to 0.04.
       gap=        Gap between line/marker and label. Defaults to 0.01 NDC.

     EXAMPLES:
       plegend, ["solid", "dot", "dash"],
                ["the solid curve", "the dotted curve", "the dashed curve"],
		width=3, height=14;
       Plot a legend with three linestyles having labels "the solid ..." etc.
       All lines have width 3. Labels are 14 points big. The legend is
       at the upper left corner of the plot.

       plegend, [1,2,3,4], ["square", "cross", "triangle", "circle"],
                color="blue", msize=0.3,
		width=[1, 1, 10, 10], origin=[0.7, 0.93];
       Plot a legend with four different plot markers, all blue, all having
       size 0.3. The first two are open symbols (width=1) the third and fourth
       are closed symbols (width=10).
       The legend is at the TOP RIGHT corner of the plot.
 */
{
   // find current viewport
   v = viewport();
   dx = v(2)-v(1);
   dy = v(4)-v(3);

   // set defaults
   if( is_void(font) )
      font = "helvetica";
   if( is_void(origin) )
      origin = [0.07, 0.93];     // default is upper left corner
   if( is_void(length) )
      length = (structof(marker)==string ? 0.04 : 0.005);
   // default line length is 0.04 NDC
   if( is_void(gap) )
      gap = 0.01;                // default gap is 0.01 NDC
   if( is_void(height) )        // default text height is 12pt
      height=12;

   // coordinates of upper-left corner of legend box
   xc = v(1) + dx*origin(1);
   yc = v(3) + dy*origin(2);

   h = 1.25 * height * 0.0013; // font height in NDC
   h *= is_void(baselinestretch) ? 1.0 : baselinestretch;
   ytext = yc - indgen( numberof(marker) ) * h;
   ymarker = ytext;

   p = plsys();
   plsys, 0;

   if( structof(marker) == string ) {
      // we have to plot line-styles
      for( i=1; i<=numberof(marker); i++ )
         if( marker(i) != "none" )
         {
           if( is_void(rgbcolor) )
             pldj, xc, ytext(i), xc+length, ytext(i),
               type = marker(i),
               width = (numberof(width)>1 ? width(i) : width),
               color = (numberof(color)>1 ? color(i) : color);
           else
             pldj, xc, ytext(i), xc+length, ytext(i),
               type = marker(i),
               width = (numberof(width)>1 ? width(i) : width),
               color = ((dimsof(color))(1)>1 ? color(,i) : color);
         }
   }
   else
   {
      // we have to plot markers
      for( i=1; i<=numberof(marker); i++ )
         if( marker(i) != 0 )
         {
           if( is_void(rgbcolor) )
             plmk, ytext(i), xc, marker=marker(i),
               width = (numberof(width)>1 ? width(i) : width),
               //               edges = (numberof(edges)>1 ? edges(i) : edges),
               color = (numberof(color)>1 ? color(i) : color),
               msize = (numberof(msize)>1 ? msize(i) : msize);
           else
             plmk, ytext(i), xc, marker=marker(i),
               width = (numberof(width)>1 ? width(i) : width),
               //               edges = (numberof(edges)>1 ? edges(i) : edges),
               color = ((dimsof(color))(1)>1 ? color(,i) : color),
               msize = (numberof(msize)>1 ? msize(i) : msize);
         }
   }
   for( i=1; i<=numberof(marker); i++ )
     if( is_void(coltext) )
       plt, text(i), xc+length+gap, ytext(i),
         tosys = 0, justify="LH", height=height, font=font;
     else
       if( is_void(rgbcolor) )
         plt, text(i), xc+length+gap, ytext(i),
           tosys = 0, justify="LH", height=height, font=font,
           color = (numberof(color)>1 ? color(i) : color);
       else
         plt, text(i), xc+length+gap, ytext(i),
           tosys = 0, justify="LH", height=height, font=font,
           color = ((dimsof(color))(1)>1 ? color(,i) : color);

   plsys, p;
}


func pltsys0( text, xc, yc, font=, height=, color=, justify=,
	      baselinestretch= )
  /* DOCUMENT
     pltsys0, text, xc, yc, font=, height=, color=;

     plot text (can be array) to system 0. Upper-left corner
     of text box is (xc,yc) RELATIVE TO CURRENT VIEWPORT. So the
     upper-left corner of the viewport is (0,1). Componenets of
     the array are plotted as lines.
     Accepts the usual text keywords font=, height=, color=, justify=,
     and baselinestretch=
  */
{
  // find current viewport
  v = viewport();
  dx = v(2)-v(1);
  dy = v(4)-v(3);

  if( is_void(height) )
    height = 12;

  if( is_void(baselinestretch) )
    baselinestretch = 1.5;

  h = baselinestretch*0.0013*height;
  if( numberof(text) == 1 )
    text = [text];

  for( i=1; i<=numberof(text); i++ )
    plt, text(i), v(1)+xc*dx, v(3)+yc*dy-i*h,
      tosys = 0, justify=justify, height=height, font=font, color=color;

}



func place_plsys( sys, x1, x2, y1, y2, style=, landscape=,
                  tmark_l=, tmark_r=, tmark_b=, tmark_u=,
                  tlabel_l=, tlabel_r=, tlabel_b=, tlabel_u=, tlabel_height=,
                  nmajor=, nminor=, nmajor_x=, nmajor_y=, nminor_x=, nminor_y=,
                  logadjmajor=, logadjminor=,
                  fcolor=, ftype=, fwidth= )
   /* DOCUMENT
      place_plsys, sys, x1, x2, y1, y2, ...;

      Place or modify a coordinate system on a Gist page 'on the fly',
      without having to create a .gs file. This function can be called
      multiple times to put more than one system on the same page.

      If a new system  is added to the drawing, it is initialized with
      the paprameters of the last system added to the current page. The first
      system put on the page is either initialized from a preexisting window,
      or by supplying the style= keyword to place_plsys in which case a new
      window will be created;

      PARAMETERS:
      sys             Modify system no. sys on the current page. If sys is
                      larger than the number of systems on the current page,
                      new systems are added.
      x1,x2,y1,y2     Viewport in NDC for the new system. No change
                      if omitted

      KEYWORDS:
      landscape=      Set the current page to landscape
      style=          Gist Style file to use for defaults [onepanel.gs]
      tmark_l=        Draw tick label numbers on left axis
      tmark_r=        Draw tick label numbers on right axis
      tmark_b=        Draw tick label numbers on bottom axis
      tmark_u=        Draw tick label numbers on top (upper) axis
      tlabel_l=       Draw tick label numbers on left axis
      tlabel_r=       Draw tick label numbers on right axis
      tlabel_b=       Draw tick label numbers on bottom axis
      tlabel_u=       Draw tick label numbers on top (upper) axis
      tlabel_height=  Height in POINTS (e.g 6,8,9,10,12,14,18) of tick mark
                      label font
      nmajor=         Scaling for major tick mark spacing
      nminor=         Scaling for minor tick mark spacing
      logadjmajor=    Scaling factor for log tick mark spacing
      logadjminor=    Scaling factor for log tick mark spacing
      fcolor=         Frame color (-1=bg -2=fg -3=b -4=w -567=rgb -8910=cmy)
      ftype=          Frame line type (0=none 1=solid 2=- 3=. 4=-. 5=-..)
      fwidth=         Frame width (1.0 is normal width of a line (1/2 point)
   */
{
   local land, systems, legends, clegends;

   l= [0n];
   if( is_void( style ) )
      style = "onepanel.gs";

   if( !raw_style(0, l, &[], &[]) )
      window, style=style;

   // read style attributes
   get_style, land, systems, legends, clegends;

   // landscape?
   if( !is_void(landscape) )
      land = landscape;

   // do we need to add a new system?
   if( sys > numberof(systems) )
      grow, systems, systems(0);

   // now fiddle around with the GfakeSystem struct in systems ...

   // viewport
   if( !is_void( y2 ) )
      systems(sys).viewport=[x1, x2, y1, y2];

   // tick mark label numbers
   if( !is_void(tlabel_b) )
   {
      if( tlabel_b )
         systems(sys).ticks.horiz.flags |= 0x020;
      else
         systems(sys).ticks.horiz.flags &= ~0x020;
   }
   if( !is_void(tlabel_u) )
   {
      if( tlabel_u )
         systems(sys).ticks.horiz.flags |= 0x040;
      else
         systems(sys).ticks.horiz.flags &= ~0x040;
   }
   if( !is_void(tlabel_l) )
   {
      if( tlabel_l )
         systems(sys).ticks.vert.flags  |= 0x020;
      else
         systems(sys).ticks.vert.flags  &= ~0x020;
   }
   if( !is_void(tlabel_r) )
   {
      if( tlabel_r )
         systems(sys).ticks.vert.flags  |= 0x040;
      else
         systems(sys).ticks.vert.flags  &= ~0x040;
   }

   // tick marks
   if( !is_void(tmark_b) )
   {
      if( tlabel_b )
         systems(sys).ticks.horiz.flags |= 0x001;
      else
         systems(sys).ticks.horiz.flags &= ~0x001;
   }
   if( !is_void(tmark_u) )
   {
      if( tlabel_u )
         systems(sys).ticks.horiz.flags |= 0x002;
      else
         systems(sys).ticks.horiz.flags &= ~0x002;
   }
   if( !is_void(tmark_l) )
   {
      if( tlabel_l )
         systems(sys).ticks.vert.flags  |= 0x001;
      else
         systems(sys).ticks.vert.flags  &= ~0x001;
   }
   if( !is_void(tmark_r) )
   {
      if( tlabel_r )
         systems(sys).ticks.vert.flags  |= 0x002;
      else
         systems(sys).ticks.vert.flags  &= ~0x002;
   }

   // tick mark label font height
   if( !is_void(tlabel_height) )
   {
      systems(sys).ticks.vert.textStyle.height  = tlabel_height*0.0013;
      systems(sys).ticks.horiz.textStyle.height = tlabel_height*0.0013;
   }

   // tick spacing
   if( !is_void(nmajor) )
   {
      systems(sys).ticks.horiz.nMajor = nmajor;
      systems(sys).ticks.vert.nMajor  = nmajor;
   }
   if( !is_void(nmajor_x) )
   {
      systems(sys).ticks.horiz.nMajor = nmajor_x;
   }
   if( !is_void(nmajor_y) )
   {
      systems(sys).ticks.vert.nMajor  = nmajor_y;
   }
   if( !is_void(nminor) )
   {
      systems(sys).ticks.horiz.nMinor = nminor;
      systems(sys).ticks.vert.nMinor  = nminor;
   }
   if( !is_void(nminor_x) )
   {
      systems(sys).ticks.horiz.nMinor = nminor_x;
   }
   if( !is_void(nminor_y) )
   {
      systems(sys).ticks.vert.nMinor  = nminor_y;
   }
   if( !is_void(logadjmajor) )
   {
      systems(sys).ticks.horiz.logAdjMajor = logadjmajor;
      systems(sys).ticks.vert.logAdjMajor  = logadjmajor;
   }
   if( !is_void(logadjminor) )
   {
      systems(sys).ticks.horiz.logAdjMinor = logadjminor;
      systems(sys).ticks.vert.logAdjMinor  = logadjminor;
   }
   if( !is_void(fcolor) )
   {
      systems(sys).ticks.horiz.tickStyle.color = fcolor;
      systems(sys).ticks.vert.tickStyle.color  = fcolor;
      systems(sys).ticks.frameStyle.color      = fcolor;
   }
   if( !is_void(ftype) )
   {
      systems(sys).ticks.horiz.tickStyle.type = ftype;
      systems(sys).ticks.vert.tickStyle.type  = ftype;
      systems(sys).ticks.frameStyle.type      = ftype;
   }
   if( !is_void(fwidth) )
   {
      systems(sys).ticks.horiz.tickStyle.width = fwidth;
      systems(sys).ticks.vert.tickStyle.width  = fwidth;
      systems(sys).ticks.frameStyle.width      = fwidth;
   }

   // finally call set_system
   set_style, land, systems, legends, clegends;
}



func plmk2(y,x,marker=,width=,color=,msize=)
/* DOCUMENT plmk2, y,x

     Make a scatter plot of the points Y versus X. Y and X  may have any
     dimensionality, but all must have the same number of elements. If X (or Y)
     is nil, it defaults to indgen(numberof(Y (or X) )).  By default, the marker
     cycles through 7 predefined marker shapes.  You may specify a shape
     using the marker= keyword, line width using the width= keyword (you
     get solid fills for width>=10), color using the color= keyword.
     You can also use the msize= keyword to scale the marker (default
     msize=1.0).  You can change the default width, color, or msize
     using the plmk_default function.

     The predefined marker= values are:
     marker=
       1	square
       2	cross
       3	triangle
       4	circle
       5	diamond
       6	cross (rotated 45 degrees)
       7	triangle (upside down)

     You may also put marker=[xm,ym] where xm and ym are vectors
     of NDC coordinates to design your own custom marker shapes.

   SEE ALSO: plmk_default, plg (type=0 keyword)
 */
{
  //if both x abd y are not defined
  if( is_void(x) && is_void(y) ) {
    write,"so what do you actually want to do?";
    return [];
  }
  //otherwise plot x,y. if x or y is undefined define them to the same defaults as plmk.
  //note. plmk2 allows also y to be undefined.
  else {
    if( is_void(x) ) x=indgen(numberof(y));
    if( is_void(y) ) y=indgen(numberof(x));
    return plmk(y(1:numberof(y)),x(1:numberof(x)),marker=marker,width=width,color=color,msize=msize);
  }

}

